@@ -8,19 +8,22 @@ set -o errexit
 # Age of Mythology
 ###
 
-script_version=20230918.1
+script_version=20240503.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
-GAME_ID='age-of-mythology-demo'
-GAME_NAME='Age of Mythology Demo'
+GAME_ID='age-of-mythology'
+GAME_NAME='Age of Mythology'
 
-ARCHIVE_BASE_0_NAME='mtrial.exe'
-ARCHIVE_BASE_0_MD5='c475268b774c0fd469802e915b3c3803'
-ARCHIVE_BASE_0_TYPE='cabinet'
-ARCHIVE_BASE_0_SIZE='550000'
-ARCHIVE_BASE_0_VERSION='1.0-archiveorg1'
-ARCHIVE_BASE_0_URL='https://archive.org/details/AgeOfMythologyDemo'
+GAME_ID_DEMO="${GAME_ID}-demo"
+GAME_NAME_DEMO="$GAME_NAME (demo)"
+
+ARCHIVE_BASE_DEMO_0_NAME='mtrial.exe'
+ARCHIVE_BASE_DEMO_0_MD5='c475268b774c0fd469802e915b3c3803'
+ARCHIVE_BASE_DEMO_0_TYPE='cabinet'
+ARCHIVE_BASE_DEMO_0_SIZE='550000'
+ARCHIVE_BASE_DEMO_0_VERSION='1.0-archiveorg1'
+ARCHIVE_BASE_DEMO_0_URL='https://archive.org/details/AgeOfMythologyDemo'
 
 CONTENT_PATH_DEFAULT='aom'
 CONTENT_GAME_BIN_FILES='
@@ -29,16 +32,21 @@ CONTENT_GAME_BIN_FILES='
 CONTENT_GAME0_BIN_PATH='.'
 CONTENT_GAME0_BIN_FILES='
 *.dll'
+CONTENT_FONTS_DATA_FILES='
+arialuni.ttf
+gio_bk.ttf
+per_____.ttf'
+CONTENT_FONTS0_DATA_PATH='.'
+CONTENT_FONTS0_DATA_FILES='
+georgiab.ttf
+georgiai.ttf
+georgia.ttf
+georgiaz.ttf'
 CONTENT_GAME_DATA_FILES='
 *'
 CONTENT_DOC_DATA_PATH='.'
 CONTENT_DOC_DATA_FILES='
 *.rtf'
-CONTENT_FONTS_FILES='
-*.ttf'
-CONTENT_FONTS0_PATH='.'
-CONTENT_FONTS0_FILES='
-*.ttf'
 
 USER_PERSISTENT_FILES='
 startup/persistent.cfg
@@ -56,13 +64,17 @@ users'
 
 APP_MAIN_EXE='aom.exe'
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
 
 PKG_BIN_ARCH='32'
 PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
 
 # Load common functions
 
@@ -95,7 +107,7 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Rename files with truncated names
+	## Rename files with truncated names.
 	mv 'gfxcon_1' 'gfxconfig'
 	mv 'godpow_1' 'god powers'
 	mv 'sound/cinema_1' 'sound/cinematics'
@@ -887,33 +899,18 @@ archive_extraction_default
 	mv 'zoneac_1.dll' 'zoneaccessapi.dll'
 )
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
-# Include shipped fonts
-
-## TODO: The ./play.it library should provide a function path_fonts (or path_fonts_ttf?) returning this path.
-PATH_FONTS="$(option_value 'prefix')/share/fonts/truetype/$(game_id)"
-content_inclusion 'FONTS' 'PKG_DATA' "$PATH_FONTS"
-content_inclusion 'FONTS0' 'PKG_DATA' "$PATH_FONTS"
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
