@@ -7,24 +7,27 @@ set -o errexit
 # Alpha Centauri
 ###
 
-script_version=20240528.2
+script_version=20240710.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='alpha-centauri'
 GAME_NAME='Alpha Centauri'
 
+## gog.com Windows installer
 ARCHIVE_BASE_0_NAME='setup_sid_meiers_alpha_centauri_2.0.2.23.exe'
 ARCHIVE_BASE_0_MD5='6c9bd7e1cf88fdbfa0e75f694bf8b0e5'
 ARCHIVE_BASE_0_TYPE='innosetup'
 ARCHIVE_BASE_0_VERSION='6.0b-gog2.0.2.23'
-ARCHIVE_BASE_0_SIZE='620000'
+ARCHIVE_BASE_0_SIZE='609309'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/sid_meiers_alpha_centauri'
 
+## Loki native Linux engine
 ARCHIVE_REQUIRED_ENGINE_NAME='alpha-centauri-linux.tar.xz'
 ARCHIVE_REQUIRED_ENGINE_MD5='a13676f2bdf1d3570ebb1835c2e4b2e8'
 ARCHIVE_REQUIRED_ENGINE_URL='https://downloads.dotslashplay.it/games/alpha-centauri/'
 
+## Optional icons pack
 ARCHIVE_OPTIONAL_ICONS_NAME='alpha-centauri-icons.2022-10-04.tar.gz'
 ARCHIVE_OPTIONAL_ICONS_MD5='9293b41c5b0ab978ff007f78d29fbbcf'
 ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/alpha-centauri/'
@@ -132,30 +135,28 @@ smac_xp2000_readme.txt'
 
 APP_MAIN_EXE='smac.dynamic'
 APP_MAIN_ICON='terran.exe'
-## Work around font rendering issues
-APP_MAIN_PRERUN='# Work around font rendering issues
+## Work around font rendering issues.
+APP_MAIN_PRERUN='
+# Work around font rendering issues
 export FREETYPE_PROPERTIES="truetype:interpreter-version=35"
 '
-APP_SMACX_PRERUN="$APP_MAIN_PRERUN"
 
 APP_SMACX_ID="${GAME_ID}-alien-crossfire"
 APP_SMACX_NAME="$GAME_NAME - Alien Crossfire"
 APP_SMACX_EXE='smacx.dynamic'
 APP_SMACX_ICON='terranx.exe'
+## Work around font rendering issues.
+APP_SMACX_PRERUN="$APP_MAIN_PRERUN"
 
 PACKAGES_LIST='
 PKG_BIN
 PKG_MOVIES
 PKG_DATA'
 
-PKG_MOVIES_ID="${GAME_ID}-movies"
-PKG_MOVIES_DESCRIPTION='movies'
-
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID $PKG_MOVIES_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_MOVIES
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libEGL.so.1
@@ -168,6 +169,12 @@ libSDL_ttf-2.0.so.0
 libsmpeg-0.4.so.0
 libz.so.1'
 
+PKG_MOVIES_ID="${GAME_ID}-movies"
+PKG_MOVIES_DESCRIPTION='movies'
+
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 PRELOAD_HACKS_LIST='
 HACK_SDL1COMPAT'
 
@@ -234,16 +241,16 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Check for the presence of the extra required archives
+# Check for the presence of the archive providing the native Linux engine
 
 archive_initialize_required \
 	'ARCHIVE_ENGINE' \
 	'ARCHIVE_REQUIRED_ENGINE'
 
-# Check for the presence of the "rename" command
-# On Arch Linux is is provided under the name "perl-rename"
+# Check that the "rename" command is available
 
 unset RENAME_CMD
+## On Arch Linux is is provided under the name "perl-rename".
 for rename_cmd in 'perl-rename' 'rename'; do
 	if command -v "$rename_cmd" >/dev/null 2>&1; then
 		RENAME_CMD="$rename_cmd"
@@ -255,7 +262,7 @@ if [ -z "${RENAME_CMD:-}" ]; then
 	exit 1
 fi
 
-# Build and include the LD_PRELOAD shims
+# Build and include the LD_PRELOAD shim required for the old engine to run on top of modern libraries
 
 hacks_inclusion_default
 
@@ -266,20 +273,20 @@ archive_extraction 'ARCHIVE_ENGINE'
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Drop unused alternative art assets.
+	## Drop unused alternative art assets.
 	rm --force --recursive \
 		'alternative art' \
 		'color blind palette'
 
-	# Replace spaces in files names by underscores
+	## Replace spaces in file paths by underscores.
 	find . -depth -name '* *' -execdir \
 		"$RENAME_CMD" 's/ /_/g' {} +
 
-	# Convert text files to UNIX-style line breaks
+	## Convert text files to UNIX-style line breaks.
 	find . -type f -name '*.txt' -exec \
 		dos2unix --quiet {} +
 
-	# Move data files into the expected paths
+	## Move data files into the expected paths.
 	mkdir 'data'
 	mv --target-directory='data' \
 		'facs' \
@@ -296,12 +303,12 @@ archive_extraction 'ARCHIVE_ENGINE'
 		*.txt
 	mv 'scenarios/alpha_centauri_scenarios' 'data/scenarios'
 
-	# Convert movies from the original format
+	## Convert movies from the original format.
 	FFMPEG_OPTIONS_COMMON='-loglevel quiet'
 	FFMPEG_OPTIONS_VIDEO='-codec:v mpeg1video -b:v 1727k -minrate 1727k -maxrate 1727k -r 29.97'
 	FFMPEG_OPTIONS_AUDIO='-codec:a mp2 -ar 44100'
 	MPLEX_OPTIONS='--verbose 0 --video-buffer 500'
-	case "${LANG%_*}" in
+	case "$(messages_language)" in
 		('fr')
 			message_begin='Conversion des fichiers vidéo, cette étape peut prendre plusieurs minutes…\n'
 			message_file='Conversion de %s…\n'
