@@ -8,9 +8,9 @@ set -o errexit
 # Anachronox
 ###
 
-script_version=20240408.1
+script_version=20240710.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='anachronox'
 GAME_NAME='Anachronox'
@@ -18,7 +18,7 @@ GAME_NAME='Anachronox'
 ARCHIVE_BASE_1_NAME='setup_anachronox_1.02_(22258).exe'
 ARCHIVE_BASE_1_MD5='4e23d4f7637f6914a7cd6c13feb7ad7d'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_SIZE='1100000'
+ARCHIVE_BASE_1_SIZE='1074901'
 ARCHIVE_BASE_1_VERSION='1.02-gog22258'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/anachronox'
 
@@ -33,20 +33,37 @@ CONTENT_PATH_DEFAULT_0='app'
 CONTENT_GAME_BIN_FILES='
 anoxdata/miles
 anoxdata/plugins
-*.dll
-*.exe
-*.inf
-*.ini
-*.ocx'
+anoxaux.dll
+anoxgfx.dll
+gamex86.dll
+ijl15.dll
+libpng13a.dll
+metagl.dll
+mss32.dll
+msvcp60.dll
+msvcrt.dll
+patch.dll
+ref_gl.dll
+zlib.dll
+afscmd.exe
+anox.exe
+autorun.exe
+dparse.exe
+gct setup.exe
+particleman.exe
+setupanox.exe
+autorun.inf
+gct setup.ini
+mscomctl.ocx'
 CONTENT_GAME_DATA_FILES='
 anoxdata
 anox.ico
-*.jpg'
+anachronox_word.jpg'
 CONTENT_DOC_DATA_FILES='
 manual.pdf
 readme.htm
-*readme.txt
-*.rtf'
+anachronox patch 1_02.rtf
+*readme.txt'
 
 USER_PERSISTENT_DIRECTORIES='
 anoxdata/save'
@@ -61,12 +78,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -95,17 +113,6 @@ fi
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Delete unwanted files.
-	## TODO: Use a more explicit list of files to include, so this is no longer required.
-	rm --force --recursive \
-		'__redist' \
-		'commonappdata' \
-		'galaxy_anachronox_2.1.0.29.exe' \
-		'tmp'
-)
 
 # Include game data
 
