@@ -9,16 +9,16 @@ set -o errexit
 # Bastion
 ###
 
-script_version=20240408.1
+script_version=20240710.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='bastion'
 GAME_NAME='Bastion'
 
 ARCHIVE_BASE_GOG_3_NAME='bastion_1_0_1747_initial_test_33876.sh'
 ARCHIVE_BASE_GOG_3_MD5='b4edf5e95e952a35bfde0c12959134ab'
-ARCHIVE_BASE_GOG_3_SIZE='1300000'
+ARCHIVE_BASE_GOG_3_SIZE='1285709'
 ARCHIVE_BASE_GOG_3_VERSION='1.50436-gog33876'
 ARCHIVE_BASE_GOG_3_URL='https://www.gog.com/game/bastion'
 
@@ -41,14 +41,14 @@ ARCHIVE_BASE_HUMBLE_0_NAME='bastion-10162016-bin'
 ARCHIVE_BASE_HUMBLE_0_MD5='19fea173ff2da0f990f60bd5e7c3b237'
 ## This is a MojoSetup installer, not relying on Makeself.
 ARCHIVE_BASE_HUMBLE_0_EXTRACTOR='bsdtar'
-ARCHIVE_BASE_HUMBLE_0_SIZE='1300000'
+ARCHIVE_BASE_HUMBLE_0_SIZE='1253966'
 ARCHIVE_BASE_HUMBLE_0_VERSION='1.2.20161020-humble161019'
 
 CONTENT_PATH_DEFAULT_GOG='data/noarch/game'
 CONTENT_PATH_DEFAULT_HUMBLE='data'
 CONTENT_GAME_MAIN_FILES='
-Bastion.exe
 Bastion.bmp
+Bastion.exe
 gamecontrollerdb.txt
 mono
 monomachineconfig
@@ -97,6 +97,8 @@ PKG_MAIN
 PKG_LIBS32
 PKG_LIBS64'
 
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_LIBS'
 PKG_MAIN_DEPENDENCIES_LIBRARIES='
 libGL.so.1
 libSDL2-2.0.so.0
@@ -118,10 +120,9 @@ System.Xml.Linq.dll'
 
 PKG_LIBS_ID="${GAME_ID}-libs"
 PKG_LIBS64_ID="$PKG_LIBS_ID"
-PKG_LIBS64_ARCH='64'
 PKG_LIBS32_ID="$PKG_LIBS_ID"
+PKG_LIBS64_ARCH='64'
 PKG_LIBS32_ARCH='32'
-PKG_MAIN_DEPS="${PKG_MAIN_DEPS:-} $PKG_LIBS_ID"
 
 # Load common functions
 
