@@ -8,9 +8,9 @@ set -o errexit
 # Beyond Good and Evil
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='beyond-good-and-evil'
 GAME_NAME='Beyond Good and Evil'
@@ -18,14 +18,17 @@ GAME_NAME='Beyond Good and Evil'
 ARCHIVE_BASE_0_NAME='setup_beyond_good_and_evil_2.1.0.9.exe'
 ARCHIVE_BASE_0_MD5='fdfa4b94cf02e24523b01c9d54568482'
 ARCHIVE_BASE_0_TYPE='innosetup'
-ARCHIVE_BASE_0_SIZE='2200000'
+ARCHIVE_BASE_0_SIZE='2195754'
 ARCHIVE_BASE_0_VERSION='1.0-gog2.1.0.9'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/beyond_good_and_evil'
 
 CONTENT_PATH_DEFAULT='app'
 CONTENT_GAME_BIN_FILES='
-*.dll
-*.exe'
+binkw32.dll
+bge.exe
+checkapplication.exe
+run.exe
+settingsapplication.exe'
 CONTENT_GAME0_BIN_PATH='sys'
 CONTENT_GAME0_BIN_FILES='
 eax.dll'
@@ -48,7 +51,7 @@ APP_MAIN_EXE='run.exe'
 APP_MAIN_ICON='bge.exe'
 ## Hide EAX library from the game, this helps avoiding some sound issues.
 ## The library should still be available to the settings application.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # Hide EAX library from the game, this helps avoiding some sound issues.
 rm --force eax.dll
 '
@@ -62,13 +65,14 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
-# Set install path in registry.
+# Set install path in registry
 
 install_path="C:\\\\${GAME_ID}"
 registry_dump_install_file='registry-dumps/install-path.reg'
@@ -125,13 +129,6 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Delete unwanted files.
-	## TODO: Using a more specific list of files to include would allow to drop this step.
-	rm --force --recursive \
-		'__support' \
-		'gameuxinstallhelper.dll' \
-		'goggame-1207658746.dll'
-
 	## Set install path in registry.
 	mkdir --parents "$(dirname "$registry_dump_install_file")"
 	printf '%s' "$registry_dump_install_content" | \
