@@ -8,9 +8,9 @@ set -o errexit
 # - Perpetual Edition
 ###
 
-script_version=20231211.1
+script_version=20240531.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='book-of-hours'
 GAME_NAME='Book of Hours'
@@ -22,21 +22,21 @@ EXPANSION_NAME_PERPETUAL='Perpetual Edition'
 
 ## Perpetual Edition
 
+ARCHIVE_BASE_PERPETUAL_8_NAME='book_of_hours_perpetual_edition_content_2024_3_e_15_72083.sh'
+ARCHIVE_BASE_PERPETUAL_8_MD5='2b21b55d6889a4c18ae57cbb1b22cb04'
+ARCHIVE_BASE_PERPETUAL_8_SIZE='75087'
+ARCHIVE_BASE_PERPETUAL_8_VERSION='2024.03.e.15-gog72083'
+
+ARCHIVE_BASE_PERPETUAL_7_NAME='book_of_hours_perpetual_edition_content_2024_2_e_11_71531.sh'
+ARCHIVE_BASE_PERPETUAL_7_MD5='a120f5371c1297a8ae13095b7ee3ccdb'
+ARCHIVE_BASE_PERPETUAL_7_SIZE='75087'
+ARCHIVE_BASE_PERPETUAL_7_VERSION='2024.02.e.11-gog71531'
+
 ARCHIVE_BASE_PERPETUAL_6_NAME='book_of_hours_perpetual_edition_content_2023_12_d_12_69519.sh'
 ARCHIVE_BASE_PERPETUAL_6_MD5='77796819b6f4a466fed0638fcb685412'
 ARCHIVE_BASE_PERPETUAL_6_SIZE='75408'
 ARCHIVE_BASE_PERPETUAL_6_VERSION='2023.12.d.12-gog69519'
 
-ARCHIVE_BASE_PERPETUAL_5_NAME='book_of_hours_perpetual_edition_content_2023_12_d_9_69348.sh'
-ARCHIVE_BASE_PERPETUAL_5_MD5='dd9891959a3098f5594655dcab33f004'
-ARCHIVE_BASE_PERPETUAL_5_SIZE='75404'
-ARCHIVE_BASE_PERPETUAL_5_VERSION='2023.12.d.9-gog69348'
-
-ARCHIVE_BASE_PERPETUAL_4_NAME='book_of_hours_perpetual_edition_content_2023_12_d_8_69334.sh'
-ARCHIVE_BASE_PERPETUAL_4_MD5='70d941a28f905cc1b31e8670594f797d'
-ARCHIVE_BASE_PERPETUAL_4_SIZE='75408'
-ARCHIVE_BASE_PERPETUAL_4_VERSION='2023.12.d.8-gog69334'
-
 ARCHIVE_BASE_PERPETUAL_3_NAME='book_of_hours_perpetual_edition_content_2023_11_d_4_69228.sh'
 ARCHIVE_BASE_PERPETUAL_3_MD5='d5bb3e49df9b8c142ac25aed53c78d01'
 ARCHIVE_BASE_PERPETUAL_3_SIZE='75404'
