@@ -7,28 +7,33 @@ set -o errexit
 # Book of Hours
 ###
 
-script_version=20231211.1
+script_version=20240531.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='book-of-hours'
 GAME_NAME='Book of Hours'
 
+ARCHIVE_BASE_10_NAME='book_of_hours_2024_3_e_17_72226.sh'
+ARCHIVE_BASE_10_MD5='c4185397829ad4d98a7fa25eddd24235'
+ARCHIVE_BASE_10_SIZE='2028310'
+ARCHIVE_BASE_10_VERSION='2024.03.e.17-gog72226'
+ARCHIVE_BASE_10_URL='https://www.gog.com/game/book_of_hours'
+
+ARCHIVE_BASE_9_NAME='book_of_hours_2024_3_e_15_72083.sh'
+ARCHIVE_BASE_9_MD5='b0c6523f10007bfca845adf6d03000f7'
+ARCHIVE_BASE_9_SIZE='2024832'
+ARCHIVE_BASE_9_VERSION='2024.03.e.15-gog72083'
+
+ARCHIVE_BASE_8_NAME='book_of_hours_2024_2_e_11_71531.sh'
+ARCHIVE_BASE_8_MD5='253b536e020ae39d617cc0746be3d5ee'
+ARCHIVE_BASE_8_SIZE='1998185'
+ARCHIVE_BASE_8_VERSION='2024.02.e.11-gog71531'
+
 ARCHIVE_BASE_7_NAME='book_of_hours_2023_12_d_12_69519.sh'
 ARCHIVE_BASE_7_MD5='f99ac227e448683eb9cb9586e0d43cc8'
 ARCHIVE_BASE_7_SIZE='1938644'
 ARCHIVE_BASE_7_VERSION='2023.12.d.12-gog69519'
-ARCHIVE_BASE_7_URL='https://www.gog.com/game/book_of_hours'
-
-ARCHIVE_BASE_6_NAME='book_of_hours_2023_12_d_9_69348.sh'
-ARCHIVE_BASE_6_MD5='0134334eccc16c6f956f8889347c79e7'
-ARCHIVE_BASE_6_SIZE='1938312'
-ARCHIVE_BASE_6_VERSION='2023.12.d.9-gog69348'
-
-ARCHIVE_BASE_5_NAME='book_of_hours_2023_12_d_8_69334.sh'
-ARCHIVE_BASE_5_MD5='13af4a42136e9fa4de6130df9b9c7034'
-ARCHIVE_BASE_5_SIZE='1938304'
-ARCHIVE_BASE_5_VERSION='2023.12.d.8-gog69334'
 
 ARCHIVE_BASE_4_NAME='book_of_hours_2023_11_d_4_69228.sh'
 ARCHIVE_BASE_4_MD5='f0dfed821caeb83d795a176dd9571281'
@@ -56,6 +61,8 @@ ARCHIVE_BASE_0_SIZE='2900000'
 ARCHIVE_BASE_0_VERSION='2023.08.a.7.2-gog66829'
 
 UNITY3D_NAME='bh'
+## Prevent inclusion of Steam libraries.
+UNITY3D_PLUGINS=' '
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 
@@ -108,14 +115,12 @@ archive_extraction_default
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
