@@ -7,9 +7,9 @@ set -o errexit
 # Caesar 3
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='caesar-3'
 GAME_NAME='Cæsar Ⅲ'
@@ -63,13 +63,13 @@ CONTENT_GAME_DATA_FILES='
 555
 smk
 wavs
+mission1.pak
+c3_model.txt
 *.555
 *.emp
 *.eng
 *.map
-*.sg2
-c3_model.txt
-mission1.pak'
+*.sg2'
 CONTENT_GAME_BIN_PATH='.'
 CONTENT_GAME_BIN_FILES='
 julius'
@@ -78,10 +78,10 @@ readme.txt
 *.pdf'
 
 USER_PERSISTENT_FILES='
-*.ini
-*.sav
 c3_model.txt
-status.txt'
+status.txt
+*.ini
+*.sav'
 
 APP_MAIN_EXE='julius'
 APP_MAIN_ICON='c3.exe'
@@ -90,17 +90,18 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libm.so.6
 libSDL2-2.0.so.0
 libSDL2_mixer-2.0.so.0'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -126,7 +127,7 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Check for the presence of the Julius engine archive.
+# Check for the presence of the archive providing the Julius engine
 # cf. https://github.com/bvschaik/julius
 
 archive_initialize_required 'ARCHIVE_JULIUS' \
