@@ -9,9 +9,9 @@ set -o errexit
 # - Paws and Claws
 ###
 
-script_version=20240416.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='children-of-morta'
 GAME_NAME='Children of Morta'
@@ -28,7 +28,7 @@ EXPANSION_NAME_PAWS='Paws and Claws'
 
 ARCHIVE_BASE_ANCIENT_0_NAME='backers_dlc_1_2_63_48061.sh'
 ARCHIVE_BASE_ANCIENT_0_MD5='931cfdfd304b909efbe61ac4d6c10b34'
-ARCHIVE_BASE_ANCIENT_0_SIZE='1400'
+ARCHIVE_BASE_ANCIENT_0_SIZE='1026'
 ARCHIVE_BASE_ANCIENT_0_VERSION='1.2.63-gog48061'
 ARCHIVE_BASE_ANCIENT_0_URL='https://www.gog.com/en/game/children_of_morta_ancient_spirits'
 
@@ -36,7 +36,7 @@ ARCHIVE_BASE_ANCIENT_0_URL='https://www.gog.com/en/game/children_of_morta_ancien
 
 ARCHIVE_BASE_PAWS_0_NAME='children_of_morta_paws_and_claws_1_2_63_48061.sh'
 ARCHIVE_BASE_PAWS_0_MD5='09efef01a9bd0c1a5172e1fe7fd19530'
-ARCHIVE_BASE_PAWS_0_SIZE='1400'
+ARCHIVE_BASE_PAWS_0_SIZE='1026'
 ARCHIVE_BASE_PAWS_0_VERSION='1.2.63-gog48061'
 ARCHIVE_BASE_PAWS_0_URL='https://www.gog.com/en/game/children_of_morta_paws_and_claws'
 
@@ -45,7 +45,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 goggame-*.info'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
