@@ -7,23 +7,21 @@ set -o errexit
 # Children of Morta
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='children-of-morta'
 GAME_NAME='Children of Morta'
 
 ARCHIVE_BASE_0_NAME='children_of_morta_1_2_63_48061.sh'
 ARCHIVE_BASE_0_MD5='3f70026a2f2adf1eff19c25041e94a3e'
-ARCHIVE_BASE_0_SIZE='1400000'
+ARCHIVE_BASE_0_SIZE='1309191'
 ARCHIVE_BASE_0_VERSION='1.2.63-gog48061'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/children_of_morta'
 
 UNITY3D_NAME='ChildrenOfMorta'
-## TODO: Check if lib_burst_generated.so is actually required.
 UNITY3D_PLUGINS='
-lib_burst_generated.so
 libfmodL.so
 libfmod.so
 libfmodstudioL.so
@@ -38,11 +36,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libatk-1.0.so.0
 libcairo.so.2
@@ -66,6 +62,9 @@ librt.so.1
 libstdc++.so.6
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
