@@ -7,9 +7,9 @@ set -o errexit
 # Dark Reign 2
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='dark-reign-2'
 GAME_NAME='Dark Reign 2'
@@ -17,8 +17,8 @@ GAME_NAME='Dark Reign 2'
 ARCHIVE_BASE_1_NAME='setup_dark_reign_2_1.3_(56283).exe'
 ARCHIVE_BASE_1_MD5='23b441f1a8ffd5302e7cde3c1099cb73'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_VERSION='1.3.882-gog'
-ARCHIVE_BASE_1_SIZE='580000'
+ARCHIVE_BASE_1_VERSION='1.3.882-gog56283'
+ARCHIVE_BASE_1_SIZE='572562'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/dark_reign_2'
 
 ARCHIVE_BASE_0_NAME='setup_dark_reign2_2.0.0.11.exe'
@@ -29,7 +29,6 @@ ARCHIVE_BASE_0_SIZE='450000'
 
 CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_0='app'
-## launcher.exe is only provided with the 2.0.0.11 GOG build.
 CONTENT_GAME_BIN_FILES='
 library
 settings.cfg
@@ -45,9 +44,15 @@ msvcp90.dll
 msvcr90.dll
 dr2.exe
 dxcfg.exe
-launcher.exe
 anet.inf
 dxcfg.ini'
+## On first launch, register the game CD-key.
+## This file is generated later in this script.
+CONTENT_GAME0_BIN_FILES='
+cdkey'
+## launcher.exe is only provided with the 2.0.0.11 GOG build.
+CONTENT_GAME1_BIN_FILES_0='
+launcher.exe'
 CONTENT_GAME_DATA_FILES='
 missions
 mods
@@ -60,9 +65,6 @@ customer_support.htm
 manual.pdf
 readme.rtf
 license.txt'
-## On first launch, register the game CD-key.
-CONTENT_GAME0_BIN_FILES='
-cdkey'
 
 USER_PERSISTENT_DIRECTORIES='
 mods
@@ -77,7 +79,7 @@ APP_MAIN_EXE='dr2.exe'
 APP_MAIN_EXE_0='launcher.exe'
 APP_MAIN_ICON='dr2.exe'
 ## On first launch, register the game CD-key.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # On first launch, register the game CD-key
 if [ ! -e .cdkey-registered ]; then
 	cdkey=$(cat cdkey)
@@ -90,12 +92,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # On first launch, register the game CD-key
 
 SCRIPT_DEPS="${SCRIPT_DEPS:-} base64 xxd"
