@@ -9,16 +9,16 @@ set -o errexit
 # Day of the Tentacle
 ###
 
-script_version=20240412.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='day-of-the-tentacle'
 GAME_NAME='Day of the Tentacle'
 
 ARCHIVE_BASE_0_NAME='gog_day_of_the_tentacle_remastered_2.1.0.2.sh'
 ARCHIVE_BASE_0_MD5='612c59c5cbdbf4d73322b46527a2d502'
-ARCHIVE_BASE_0_SIZE='2700000'
+ARCHIVE_BASE_0_SIZE='2677592'
 ARCHIVE_BASE_0_VERSION='1.4.1-gog2.1.0.2'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/day_of_the_tentacle_remastered'
 
@@ -45,7 +45,8 @@ PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -81,13 +82,6 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Force the use of system-provided SDL
-
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-# Force the use of system-provided SDL.
-export SDL_DYNAMIC_API='$(path_libraries_system)/libSDL2-2.0.so.0'
-"
-
 # Extract game data
 
 archive_extraction_default
@@ -99,6 +93,16 @@ content_inclusion_default
 
 # Write launchers
 
+## Force the use of system-provided SDL.
+path_libraries_system=$(
+	set_current_package 'PKG_BIN'
+	path_libraries_system
+)
+APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
+# Force the use of system-provided SDL.
+export SDL_DYNAMIC_API='${path_libraries_system}/libSDL2-2.0.so.0'
+"
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
