@@ -8,16 +8,16 @@ set -o errexit
 # Desperados 1
 ###
 
-script_version=20240410.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='desperados-1'
 GAME_NAME='Desperados: Wanted Dead or Alive'
 
 ARCHIVE_BASE_1_NAME='desperados_wanted_dead_or_alive_en_1_0_2_thqn_22430.sh'
 ARCHIVE_BASE_1_MD5='c4338cd7526dc01eef347408368f6bf4'
-ARCHIVE_BASE_1_SIZE='2000000'
+ARCHIVE_BASE_1_SIZE='1938955'
 ARCHIVE_BASE_1_VERSION='1.0.2-gog22430'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/desperados_wanted_dead_or_alive'
 
@@ -46,11 +46,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
@@ -60,6 +58,9 @@ libpthread.so.0
 libSDL2-2.0.so.0
 libstdc++.so.6'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
