@@ -7,9 +7,9 @@ set -o errexit
 # Desperados 3
 ###
 
-script_version=20240408.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='desperados-3'
 GAME_NAME='Desperados Ⅲ'
@@ -89,21 +89,32 @@ PKG_DATA_STREAMINGASSETS
 PKG_DATA_LEVELS
 PKG_DATA'
 
+PKG_BIN_ARCH='64'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
+video/quicktime, variant=(string)iso'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_GI
+PKG_DATA_STREAMINGASSETS
+PKG_DATA_LEVELS_1
+PKG_DATA_LEVELS_2'
+PKG_DATA_DEPENDENCIES_SIBLINGS_DEMO='
+PKG_DATA_GI
+PKG_DATA_STREAMINGASSETS
+PKG_DATA_LEVELS'
 
 PKG_DATA_GI_ID="${PKG_DATA_ID}-gi"
 PKG_DATA_GI_ID_DEMO="${PKG_DATA_ID_DEMO}-gi"
 PKG_DATA_GI_DESCRIPTION="$PKG_DATA_DESCRIPTION - gi"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_GI_ID"
-PKG_DATA_DEPS_DEMO="${PKG_DATA_DEPS_DEMO:-} $PKG_DATA_GI_ID_DEMO"
 
 PKG_DATA_STREAMINGASSETS_ID="${PKG_DATA_ID}-streamingassets"
 PKG_DATA_STREAMINGASSETS_ID_DEMO="${PKG_DATA_ID_DEMO}-streamingassets"
 PKG_DATA_STREAMINGASSETS_DESCRIPTION="$PKG_DATA_DESCRIPTION - streamingassets"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_STREAMINGASSETS_ID"
-PKG_DATA_DEPS_DEMO="${PKG_DATA_DEPS_DEMO:-} $PKG_DATA_STREAMINGASSETS_ID_DEMO"
 
 PKG_DATA_LEVELS_ID="${PKG_DATA_ID}-levels"
 PKG_DATA_LEVELS_ID_DEMO="${PKG_DATA_ID_DEMO}-levels"
@@ -112,14 +123,6 @@ PKG_DATA_LEVELS_2_ID="${PKG_DATA_LEVELS_ID}-2"
 PKG_DATA_LEVELS_DESCRIPTION="$PKG_DATA_DESCRIPTION - levels"
 PKG_DATA_LEVELS_1_DESCRIPTION="$PKG_DATA_LEVELS_DESCRIPTION - 1"
 PKG_DATA_LEVELS_2_DESCRIPTION="$PKG_DATA_LEVELS_DESCRIPTION - 2"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_LEVELS_1_ID $PKG_DATA_LEVELS_2_ID"
-PKG_DATA_DEPS_DEMO="${PKG_DATA_DEPS_DEMO:-} $PKG_DATA_LEVELS_ID_DEMO"
-
-PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
-PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
-video/quicktime, variant=(string)iso'
 
 # Load common functions
 
