@@ -8,9 +8,9 @@ set -o errexit
 # Deus Ex
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='deus-ex'
 GAME_NAME='Deus Ex'
@@ -18,7 +18,7 @@ GAME_NAME='Deus Ex'
 ARCHIVE_BASE_7_NAME='setup_deus_ex_goty_1.112fm(revision_1.6.3.0)_(51757).exe'
 ARCHIVE_BASE_7_MD5='9dd2b837300bfa19c6b5b8fde5d38df6'
 ARCHIVE_BASE_7_TYPE='innosetup'
-ARCHIVE_BASE_7_SIZE='880000'
+ARCHIVE_BASE_7_SIZE='870816'
 ARCHIVE_BASE_7_VERSION='1.112fm-gog51757'
 ARCHIVE_BASE_7_URL='https://www.gog.com/game/deus_ex'
 
@@ -96,12 +96,12 @@ system/*.exe
 system/*.ini
 system/*.int'
 CONTENT_GAME_DATA_FILES='
-system/*.u
 help
 maps
 music
 sounds
-textures'
+textures
+system/*.u'
 CONTENT_DOC_DATA_FILES='
 manual.pdf
 system/*.txt'
@@ -119,7 +119,7 @@ WINE_WINETRICKS_VERBS='csmt=off'
 
 APP_MAIN_EXE='system/deusex.exe'
 ## Run the game binary from its parent directory.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # Run the game binary from its parent directory
 cd "$(dirname "$APP_EXE")"
 APP_EXE=$(basename "$APP_EXE")
@@ -129,13 +129,14 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
-# Set OpenGL as default rendering engine
+# Set OpenGL as the default rendering engine
 
 SCRIPT_DEPS="${SCRIPT_DEPS:-} sed unix2dos"
 
@@ -181,7 +182,7 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Set OpenGL as default rendering engine.
+	## Set OpenGL as the default rendering engine.
 	ini_file='system/deusex.ini'
 	ini_field='GameRenderDevice'
 	ini_value='OpenGLDrv.OpenGLRenderDevice'
