@@ -7,13 +7,26 @@ set -o errexit
 # Disco Elysium
 ###
 
-script_version=20240521.1
+script_version=20240630.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='disco-elysium'
 GAME_NAME='Disco Elysium'
 
+ARCHIVE_BASE_5_NAME='setup_disco_elysium_-_the_final_cut_wina0a062f3_(74350).exe'
+ARCHIVE_BASE_5_MD5='52a20a526a898a173d98b800f331616c'
+ARCHIVE_BASE_5_TYPE='innosetup'
+ARCHIVE_BASE_5_PART1_NAME='setup_disco_elysium_-_the_final_cut_wina0a062f3_(74350)-1.bin'
+ARCHIVE_BASE_5_PART1_MD5='29cac3aca83c0c3ef1b0c5923b7a8f22'
+ARCHIVE_BASE_5_PART2_NAME='setup_disco_elysium_-_the_final_cut_wina0a062f3_(74350)-2.bin'
+ARCHIVE_BASE_5_PART2_MD5='82fe3cd0526d89342f41df1f58dfec01'
+ARCHIVE_BASE_5_PART3_NAME='setup_disco_elysium_-_the_final_cut_wina0a062f3_(74350)-3.bin'
+ARCHIVE_BASE_5_PART3_MD5='4cbf7779c69ca856d689cad0bc568ef3'
+ARCHIVE_BASE_5_SIZE='10074442'
+ARCHIVE_BASE_5_VERSION='1.0.a0a062f3-gog74350'
+ARCHIVE_BASE_5_URL='https://www.gog.com/game/disco_elysium'
+
 ARCHIVE_BASE_4_NAME='setup_disco_elysium_-_the_final_cut_wina0a062f1_(73330).exe'
 ARCHIVE_BASE_4_MD5='fa1ab8b1023dbdd96464e48426f724de'
 ARCHIVE_BASE_4_TYPE='innosetup'
@@ -25,7 +38,6 @@ ARCHIVE_BASE_4_PART3_NAME='setup_disco_elysium_-_the_final_cut_wina0a062f1_(7333
 ARCHIVE_BASE_4_PART3_MD5='2dff22e62041509591e11d91d5567ee0'
 ARCHIVE_BASE_4_SIZE='10076178'
 ARCHIVE_BASE_4_VERSION='1.0.a0a062f1-gog73330'
-ARCHIVE_BASE_4_URL='https://www.gog.com/game/disco_elysium'
 
 ARCHIVE_BASE_3_NAME='setup_disco_elysium_-_the_final_cut_wina0a062ed_(72872).exe'
 ARCHIVE_BASE_3_MD5='8f2bc041892c5edea9fbcf5340ad05c1'
