@@ -7,9 +7,9 @@ set -o errexit
 # Dungeon Keeper 1
 ###
 
-script_version=20240410.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='dungeon-keeper-1'
 GAME_NAME='Dungeon Keeper'
@@ -17,7 +17,7 @@ GAME_NAME='Dungeon Keeper'
 ARCHIVE_BASE_1_NAME='setup_dungeon_keeper_gold_10.1_(28184).exe'
 ARCHIVE_BASE_1_MD5='5d9c6f723c0375590cd77f79bed44eff'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_SIZE='510000'
+ARCHIVE_BASE_1_SIZE='370026'
 ARCHIVE_BASE_1_VERSION='10.1-gog28184'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/dungeon_keeper'
 
@@ -41,7 +41,9 @@ sound
 game.gog
 game.ins
 game.inst
-*.exe
+deeper.exe
+dos4gw.exe
+keeper.exe
 *.ogg'
 CONTENT_GAME0_MAIN_PATH='__support/save'
 CONTENT_GAME0_MAIN_PATH_0='app'
@@ -110,6 +112,10 @@ PKG_L10N_VOICES_EN
 PKG_L10N_VOICES_FR
 PKG_MAIN'
 
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_TXT
+PKG_L10N_VOICES'
+
 PKG_L10N_TXT_ID="${GAME_ID}-l10n-txt"
 PKG_L10N_TXT_EN_ID="${PKG_L10N_TXT_ID}-en"
 PKG_L10N_TXT_FR_ID="${PKG_L10N_TXT_ID}-fr"
@@ -130,8 +136,6 @@ PKG_L10N_VOICES_FR_PROVIDES="$PKG_L10N_VOICES_PROVIDES"
 PKG_L10N_VOICES_EN_DESCRIPTION='English voices'
 PKG_L10N_VOICES_FR_DESCRIPTION='French voices'
 
-PKG_MAIN_DEPS="$PKG_L10N_TXT_ID $PKG_L10N_VOICES_ID"
-
 # unar is used to extract the contents of the disk image
 
 SCRIPT_DEPS="${SCRIPT_DEPS:-} unar"
@@ -167,11 +171,6 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Delete unwanted files.
-	rm --force --recursive \
-		'__redist' \
-		'dosbox'
-
 	## Delete files that should not be included in the base package.
 	## These files are provided by the localization packages.
 	rm --force --recursive \
