@@ -7,9 +7,9 @@ set -o errexit
 # Dungeon Keeper 2
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='dungeon-keeper-2'
 GAME_NAME='Dungeon Keeper Ⅱ'
@@ -17,7 +17,7 @@ GAME_NAME='Dungeon Keeper Ⅱ'
 ARCHIVE_BASE_1_NAME='setup_dungeon_keeper_2_1.7_(22280).exe'
 ARCHIVE_BASE_1_TYPE='innosetup'
 ARCHIVE_BASE_1_MD5='eeb2229ee49518504884a9ac65f611ad'
-ARCHIVE_BASE_1_SIZE='510000'
+ARCHIVE_BASE_1_SIZE='500537'
 ARCHIVE_BASE_1_VERSION='1.7-gog22280'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/dungeon_keeper_2'
 
@@ -64,12 +64,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
