@@ -8,9 +8,9 @@ set -o errexit
 # - Halloween
 ###
 
-script_version=20240416.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='endzone-1'
 GAME_NAME='Endzone: A World Apart'
@@ -41,7 +41,10 @@ CONTENT_PATH_DEFAULT='.'
 CONTENT_GAME_MAIN_FILES='
 mods'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
