@@ -7,9 +7,9 @@ set -o errexit
 # Endzone 1
 ###
 
-script_version=20240408.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='endzone-1'
 GAME_NAME='Endzone: A World Apart'
@@ -47,19 +47,21 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
+PKG_BIN_ARCH='64'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
-PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
 
 # Load common functions
 
