@@ -9,9 +9,9 @@ set -o errexit
 # Faster Than Light
 ###
 
-script_version=20240410.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='faster-than-light'
 GAME_NAME='FTL: Faster Than Light'
@@ -22,7 +22,7 @@ GAME_NAME='FTL: Faster Than Light'
 
 ARCHIVE_BASE_GOG_6_NAME='ftl_advanced_edition_1_6_12_2_35269.sh'
 ARCHIVE_BASE_GOG_6_MD5='fc012e9ac7515f0b7b119a73ccfd7190'
-ARCHIVE_BASE_GOG_6_SIZE='410000'
+ARCHIVE_BASE_GOG_6_SIZE='401336'
 ARCHIVE_BASE_GOG_6_VERSION='1.6.12.2-gog35269'
 ARCHIVE_BASE_GOG_6_URL='https://www.gog.com/game/faster_than_light'
 
@@ -60,7 +60,7 @@ ARCHIVE_BASE_GOG_0_VERSION='1.6.3-gog17917'
 
 ARCHIVE_BASE_HUMBLE_2_NAME='FTL.1.6.12.Linux.zip'
 ARCHIVE_BASE_HUMBLE_2_MD5='4ee7ea561d7753c8a003570364e15311'
-ARCHIVE_BASE_HUMBLE_2_SIZE='410000'
+ARCHIVE_BASE_HUMBLE_2_SIZE='400104'
 ARCHIVE_BASE_HUMBLE_2_VERSION='1.6.12-humble191220'
 ARCHIVE_BASE_HUMBLE_2_URL='https://www.humblebundle.com/store/ftl-faster-than-light'
 
@@ -96,9 +96,9 @@ CONTENT_DOC0_DATA_FILES='
 APP_MAIN_EXE_BIN64='FTL.amd64'
 APP_MAIN_EXE_BIN32='FTL.x86'
 APP_MAIN_ICON='exe_icon.bmp'
-## Work around issues with non-US locales
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
-# Work around issues with non-US locales
+## Work around problems with non-US locales.
+APP_MAIN_PRERUN='
+# Work around problems with non-US locales
 export LANG=C
 '
 
@@ -107,14 +107,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libasound.so.2
 libc.so.6
@@ -127,6 +125,9 @@ libX11.so.6'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
