@@ -10,9 +10,9 @@ set -o errexit
 # - On The Edge
 ###
 
-script_version=20240410.1
+script_version=20240712.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='frostpunk'
 GAME_NAME='Frostpunk'
@@ -33,7 +33,7 @@ EXPANSION_NAME_EDGE='On The Edge'
 ARCHIVE_BASE_RIFTS_0_NAME='setup_frostpunk_-_szczeliny_1.6.1_51852_59618_(51757).exe'
 ARCHIVE_BASE_RIFTS_0_MD5='28b7855428687f3e819e141e78f0efce'
 ARCHIVE_BASE_RIFTS_0_TYPE='innosetup'
-ARCHIVE_BASE_RIFTS_0_SIZE='7800'
+ARCHIVE_BASE_RIFTS_0_SIZE='7457'
 ARCHIVE_BASE_RIFTS_0_VERSION='1.6.1-gog51757'
 ARCHIVE_BASE_RIFTS_0_URL='https://www.gog.com/game/frostpunk_the_rifts'
 
@@ -42,7 +42,7 @@ ARCHIVE_BASE_RIFTS_0_URL='https://www.gog.com/game/frostpunk_the_rifts'
 ARCHIVE_BASE_AUTUMN_0_NAME='setup_frostpunk_the_last_autumn_1.6.1_51852_59618_(51757).exe'
 ARCHIVE_BASE_AUTUMN_0_MD5='caf40e3e2fc0354b4a4ac130abba1f9e'
 ARCHIVE_BASE_AUTUMN_0_TYPE='innosetup'
-ARCHIVE_BASE_AUTUMN_0_SIZE='7500'
+ARCHIVE_BASE_AUTUMN_0_SIZE='7132'
 ARCHIVE_BASE_AUTUMN_0_VERSION='1.6.1-gog51757'
 ARCHIVE_BASE_AUTUMN_0_URL='https://www.gog.com/game/frostpunk_the_last_autumn'
 
@@ -51,7 +51,7 @@ ARCHIVE_BASE_AUTUMN_0_URL='https://www.gog.com/game/frostpunk_the_last_autumn'
 ARCHIVE_BASE_EDGE_0_NAME='setup_frostpunk_on_the_edge_1.6.1_51852_59618_(51757).exe'
 ARCHIVE_BASE_EDGE_0_MD5='ac91f06f1e421f0ae8061eefaaf42859'
 ARCHIVE_BASE_EDGE_0_TYPE='innosetup'
-ARCHIVE_BASE_EDGE_0_SIZE='8200'
+ARCHIVE_BASE_EDGE_0_SIZE='7926'
 ARCHIVE_BASE_EDGE_0_VERSION='1.6.1-gog51757'
 ARCHIVE_BASE_EDGE_0_URL='https://www.gog.com/game/frostpunk_on_the_edge'
 
@@ -60,7 +60,10 @@ CONTENT_PATH_DEFAULT='.'
 CONTENT_GAME_MAIN_FILES='
 goggame-*.info'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
