@@ -7,9 +7,9 @@ set -o errexit
 # Ghost Master
 ###
 
-script_version=20240410.1
+script_version=20240712.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='ghost-master'
 GAME_NAME='Ghost Master'
@@ -17,7 +17,7 @@ GAME_NAME='Ghost Master'
 ARCHIVE_BASE_1_NAME='setup_ghost_master_20171020_(15806).exe'
 ARCHIVE_BASE_1_MD5='bbc7b8d6ed9b08c54cba6f2b1048a0fd'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_SIZE='680000'
+ARCHIVE_BASE_1_SIZE='658670'
 ARCHIVE_BASE_1_VERSION='1.1-gog15806'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/ghost_master'
 
@@ -29,9 +29,11 @@ ARCHIVE_BASE_0_VERSION='1.1-gog2.0.0.3'
 
 CONTENT_PATH_DEFAULT='app/ghostdata'
 CONTENT_GAME_BIN_FILES='
-*.cfg
-*.dll
-*.exe'
+spdrv.cfg
+ogg.dll
+vorbis.dll
+vorbisfile.dll
+ghost.exe'
 CONTENT_GAME_DATA_FILES='
 characters
 cursors
@@ -51,11 +53,11 @@ sound
 text
 ui
 voice
-*.txt'
+lsize.txt'
 CONTENT_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/.."
 CONTENT_DOC_DATA_FILES='
-*.pdf
-*.txt'
+manual.pdf
+readme.txt'
 
 WINE_PERSISTENT_DIRECTORIES='
 users/Public/Documents/Ghost Master/SaveGames'
@@ -71,17 +73,18 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
 deinterlace
 video/x-ms-asf
 audio/x-wma, wmaversion=(int)1
 video/x-wmv, wmvversion=(int)1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
