@@ -7,16 +7,16 @@ set -o errexit
 # Gibbous - A Cthulhu Adventure
 ###
 
-script_version=20240410.1
+script_version=20240712.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='gibbous-a-cthulhu-adventure'
 GAME_NAME='Gibbous - A Cthulhu Adventure'
 
 ARCHIVE_BASE_0_NAME='gibbous_a_cthulhu_adventure_x86_64_1_8_35773.sh'
 ARCHIVE_BASE_0_MD5='c92315690df34ee8affa24f184486ccb'
-ARCHIVE_BASE_0_SIZE='9500000'
+ARCHIVE_BASE_0_SIZE='9478807'
 ARCHIVE_BASE_0_VERSION='1.8-gog35773'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/gibbous_a_cthulhu_adventure'
 
@@ -33,11 +33,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -52,6 +50,9 @@ librt.so.1
 libstdc++.so.6
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
