@@ -9,9 +9,9 @@ set -o errexit
 # - Forgotten Gods
 ###
 
-script_version=20231211.1
+script_version=20240628.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='grim-dawn'
 GAME_NAME='Grim Dawn'
@@ -26,6 +26,31 @@ EXPANSION_NAME_GODS='Forgotten Gods'
 
 ## Ashes of Malmouth
 
+ARCHIVE_BASE_ASHES_6_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.1_(74365).exe'
+ARCHIVE_BASE_ASHES_6_MD5='01617f6a1fae6a2d8cd68061a4b7ed71'
+ARCHIVE_BASE_ASHES_6_TYPE='innosetup'
+ARCHIVE_BASE_ASHES_6_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.1.1_(74365)-1.bin'
+ARCHIVE_BASE_ASHES_6_PART1_MD5='d687516b6ab638161aa0f8bd47416b66'
+ARCHIVE_BASE_ASHES_6_SIZE='2508370'
+ARCHIVE_BASE_ASHES_6_VERSION='1.2.1.1-gog74365'
+ARCHIVE_BASE_ASHES_6_URL='https://www.gog.com/game/grim_dawn_ashes_of_malmouth'
+
+ARCHIVE_BASE_ASHES_5_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.5a_(71558).exe'
+ARCHIVE_BASE_ASHES_5_MD5='459923324f4f32779885fe03f192fe3a'
+ARCHIVE_BASE_ASHES_5_TYPE='innosetup'
+ARCHIVE_BASE_ASHES_5_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.5a_(71558)-1.bin'
+ARCHIVE_BASE_ASHES_5_PART1_MD5='11d3e5371bb3b9ecceb0a72b99671a24'
+ARCHIVE_BASE_ASHES_5_SIZE='2508049'
+ARCHIVE_BASE_ASHES_5_VERSION='1.2.0.5a-gog71558'
+
+ARCHIVE_BASE_ASHES_4_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.5_(71516).exe'
+ARCHIVE_BASE_ASHES_4_MD5='c692033a7f8a57cfc83fe0caecf763e9'
+ARCHIVE_BASE_ASHES_4_TYPE='innosetup'
+ARCHIVE_BASE_ASHES_4_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.5_(71516)-1.bin'
+ARCHIVE_BASE_ASHES_4_PART1_MD5='270e20c090ddf4a172b3e4c7a869222b'
+ARCHIVE_BASE_ASHES_4_SIZE='2508622'
+ARCHIVE_BASE_ASHES_4_VERSION='1.2.0.5-gog71516'
+
 ARCHIVE_BASE_ASHES_3_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.3_hotfix_3_(69499).exe'
 ARCHIVE_BASE_ASHES_3_MD5='921796d60998467c4c753d80f99a6584'
 ARCHIVE_BASE_ASHES_3_TYPE='innosetup'
@@ -33,7 +58,6 @@ ARCHIVE_BASE_ASHES_3_PART1_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.3_hot
 ARCHIVE_BASE_ASHES_3_PART1_MD5='618cfba9ba745a2d3fd6e5b9ae744cb2'
 ARCHIVE_BASE_ASHES_3_SIZE='2510332'
 ARCHIVE_BASE_ASHES_3_VERSION='1.2.0.3-gog69499'
-ARCHIVE_BASE_ASHES_3_URL='https://www.gog.com/game/grim_dawn_ashes_of_malmouth'
 
 ARCHIVE_BASE_ASHES_2_NAME='setup_grim_dawn_-_ashes_of_malmouth_1.2.0.2_hotfix_2_(69134).exe'
 ARCHIVE_BASE_ASHES_2_MD5='49194993f6649141ac9f118d61eb8f90'
@@ -61,6 +85,31 @@ ARCHIVE_BASE_ASHES_0_VERSION='1.1.9.8-gog65199'
 
 ## Forgotten Gods
 
+ARCHIVE_BASE_GODS_6_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.1_(74365).exe'
+ARCHIVE_BASE_GODS_6_MD5='45e52392fb4f503b2078ddf6af6a3411'
+ARCHIVE_BASE_GODS_6_TYPE='innosetup'
+ARCHIVE_BASE_GODS_6_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.1.1_(74365)-1.bin'
+ARCHIVE_BASE_GODS_6_PART1_MD5='195f5f735715d9ae59080774d0a98bd0'
+ARCHIVE_BASE_GODS_6_SIZE='3221131'
+ARCHIVE_BASE_GODS_6_VERSION='1.2.1.1-gog74365'
+ARCHIVE_BASE_GODS_6_URL='https://www.gog.com/game/grim_dawn_forgotten_gods'
+
+ARCHIVE_BASE_GODS_5_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.5a_(71558).exe'
+ARCHIVE_BASE_GODS_5_MD5='f4e80fca2102e244a47a218171c0f336'
+ARCHIVE_BASE_GODS_5_TYPE='innosetup'
+ARCHIVE_BASE_GODS_5_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.5a_(71558)-1.bin'
+ARCHIVE_BASE_GODS_5_PART1_MD5='3199f7442939194091a2d534553b8007'
+ARCHIVE_BASE_GODS_5_SIZE='3220483'
+ARCHIVE_BASE_GODS_5_VERSION='1.2.0.5a-gog71558'
+
+ARCHIVE_BASE_GODS_4_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.5_(71516).exe'
+ARCHIVE_BASE_GODS_4_MD5='cef5d93af87d3a4690bca2f78eb6e172'
+ARCHIVE_BASE_GODS_4_TYPE='innosetup'
+ARCHIVE_BASE_GODS_4_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.5_(71516)-1.bin'
+ARCHIVE_BASE_GODS_4_PART1_MD5='8079bd9c7dfbf5234355bd9ecb56d524'
+ARCHIVE_BASE_GODS_4_SIZE='3220210'
+ARCHIVE_BASE_GODS_4_VERSION='1.2.0.5-gog71516'
+
 ARCHIVE_BASE_GODS_3_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.3_hotfix_3_(69499).exe'
 ARCHIVE_BASE_GODS_3_MD5='75b0ed8db6996ae3b5fb4df2177b8507'
 ARCHIVE_BASE_GODS_3_TYPE='innosetup'
@@ -68,7 +117,6 @@ ARCHIVE_BASE_GODS_3_PART1_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.3_hotfix_
 ARCHIVE_BASE_GODS_3_PART1_MD5='a0c5c5a18b150c8349d247c593fb71d5'
 ARCHIVE_BASE_GODS_3_SIZE='3220424'
 ARCHIVE_BASE_GODS_3_VERSION='1.2.0.3-gog69499'
-ARCHIVE_BASE_GODS_3_URL='https://www.gog.com/game/grim_dawn_forgotten_gods'
 
 ARCHIVE_BASE_GODS_2_NAME='setup_grim_dawn_-_forgotten_gods_1.2.0.2_hotfix_2_(69134).exe'
 ARCHIVE_BASE_GODS_2_MD5='3506b7cfcbb6b475b8c182024932d332'
