@@ -7,13 +7,38 @@ set -o errexit
 # Grim Dawn
 ###
 
-script_version=20231211.1
+script_version=20240628.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='grim-dawn'
 GAME_NAME='Grim Dawn'
 
+ARCHIVE_BASE_6_NAME='setup_grim_dawn_1.2.1.1_(64bit)_(74365).exe'
+ARCHIVE_BASE_6_MD5='419c765ff7d14cc19142774ae44c3eb9'
+ARCHIVE_BASE_6_TYPE='innosetup'
+ARCHIVE_BASE_6_PART1_NAME='setup_grim_dawn_1.2.1.1_(64bit)_(74365)-1.bin'
+ARCHIVE_BASE_6_PART1_MD5='e3f6f66a0aa88c6f7a47e9c6a07c208b'
+ARCHIVE_BASE_6_SIZE='4787490'
+ARCHIVE_BASE_6_VERSION='1.2.1.1-gog74365'
+ARCHIVE_BASE_6_URL='https://www.gog.com/game/grim_dawn'
+
+ARCHIVE_BASE_5_NAME='setup_grim_dawn_1.2.0.5a_(64bit)_(71558).exe'
+ARCHIVE_BASE_5_MD5='f232c25a9c69a5776dd4ce65b40df6df'
+ARCHIVE_BASE_5_TYPE='innosetup'
+ARCHIVE_BASE_5_PART1_NAME='setup_grim_dawn_1.2.0.5a_(64bit)_(71558)-1.bin'
+ARCHIVE_BASE_5_PART1_MD5='c78a59aa61b124030e6d96cabaaabd2d'
+ARCHIVE_BASE_5_SIZE='4768460'
+ARCHIVE_BASE_5_VERSION='1.2.0.5a-gog71558'
+
+ARCHIVE_BASE_4_NAME='setup_grim_dawn_1.2.0.5_(64bit)_(71516).exe'
+ARCHIVE_BASE_4_MD5='0ec082fed3fa62b70979fcf9fd5ed919'
+ARCHIVE_BASE_4_TYPE='innosetup'
+ARCHIVE_BASE_4_PART1_NAME='setup_grim_dawn_1.2.0.5_(64bit)_(71516)-1.bin'
+ARCHIVE_BASE_4_PART1_MD5='8f7dd61efc9962fddd88dc19da4a8efe'
+ARCHIVE_BASE_4_SIZE='4767825'
+ARCHIVE_BASE_4_VERSION='1.2.0.5-gog71516'
+
 ARCHIVE_BASE_3_NAME='setup_grim_dawn_1.2.0.3_hotfix_3_(64bit)_(69499).exe'
 ARCHIVE_BASE_3_MD5='d407d7f0c13b2e9a09c9d507a6dd9406'
 ARCHIVE_BASE_3_TYPE='innosetup'
@@ -21,7 +46,6 @@ ARCHIVE_BASE_3_PART1_NAME='setup_grim_dawn_1.2.0.3_hotfix_3_(64bit)_(69499)-1.bi
 ARCHIVE_BASE_3_PART1_MD5='cb0b21ec562a0023650928cabd3f2aac'
 ARCHIVE_BASE_3_SIZE='4716376'
 ARCHIVE_BASE_3_VERSION='1.2.0.3-gog69499'
-ARCHIVE_BASE_3_URL='https://www.gog.com/game/grim_dawn'
 
 ARCHIVE_BASE_2_NAME='setup_grim_dawn_1.2.0.2_hotfix_2_(64bit)_(69134).exe'
 ARCHIVE_BASE_2_MD5='a86614183a27085a644642e73c89dc31'
@@ -48,6 +72,7 @@ ARCHIVE_BASE_0_SIZE='4332472'
 ARCHIVE_BASE_0_VERSION='1.1.9.8-gog65199'
 
 CONTENT_PATH_DEFAULT='.'
+## TODO: Set an explicit list of .dll and .exe files.
 CONTENT_GAME_BIN_FILES='
 x64
 *.dll
@@ -119,14 +144,12 @@ archive_extraction_default
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
