@@ -7,9 +7,9 @@ set -o errexit
 # Heroes of Might and Magic 4
 ###
 
-script_version=20240408.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='heroes-of-might-and-magic-4'
 GAME_NAME='Heroes of Might and Magic Ⅳ'
@@ -120,26 +120,28 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_ID_EN="${PKG_DATA_ID}-en"
-PKG_DATA_ID_FR="${PKG_DATA_ID}-fr"
+PKG_BIN_ARCH='32'
+PKG_BIN_BASE_ID="$GAME_ID"
+PKG_BIN_ID_EN="${PKG_BIN_BASE_ID}-en"
+PKG_BIN_ID_FR="${PKG_BIN_BASE_ID}-fr"
+PKG_BIN_PROVIDES="
+$PKG_BIN_BASE_ID"
+PKG_BIN_DESCRIPTION_EN='English version'
+PKG_BIN_DESCRIPTION_FR='French version'
+## A dependency on the language-specific variant of the data package is set,
+## not on the common name provided by both variants of this package.
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
+PKG_DATA_BASE_ID="${GAME_ID}-data"
+PKG_DATA_ID_EN="${PKG_DATA_BASE_ID}-en"
+PKG_DATA_ID_FR="${PKG_DATA_BASE_ID}-fr"
 PKG_DATA_PROVIDES="
-$PKG_DATA_ID"
+$PKG_DATA_BASE_ID"
 PKG_DATA_DESCRIPTION='data'
 PKG_DATA_DESCRIPTION_EN="${PKG_DATA_DESCRIPTION} - English version"
 PKG_DATA_DESCRIPTION_FR="${PKG_DATA_DESCRIPTION} - French version"
 
-PKG_BIN_ARCH='32'
-PKG_BIN_ID="$GAME_ID"
-PKG_BIN_ID_EN="${PKG_BIN_ID}-en"
-PKG_BIN_ID_FR="${PKG_BIN_ID}-fr"
-PKG_BIN_PROVIDES="
-$PKG_BIN_ID"
-PKG_BIN_DESCRIPTION_EN='English version'
-PKG_BIN_DESCRIPTION_FR='French version'
-PKG_BIN_DEPS_EN="$PKG_DATA_ID_EN"
-PKG_BIN_DEPS_FR="$PKG_DATA_ID_FR"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
