@@ -9,9 +9,9 @@ set -o errexit
 # - Tribes of the East stand-alone expansion
 ###
 
-script_version=20240410.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='heroes-of-might-and-magic-5'
 GAME_NAME='Heroes of Might and Magic Ⅴ'
@@ -174,16 +174,21 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
-PKG_L10N_ID_TOTE="${GAME_ID_TOTE}-l10n"
-PKG_L10N_ID_TOTE_EN="${PKG_L10N_ID_TOTE}-en"
-PKG_L10N_ID_TOTE_FR="${PKG_L10N_ID_TOTE}-fr"
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
+PKG_L10N_BASE_ID_TOTE="${GAME_ID_TOTE}-l10n"
+PKG_L10N_ID_TOTE_EN="${PKG_L10N_BASE_ID_TOTE}-en"
+PKG_L10N_ID_TOTE_FR="${PKG_L10N_BASE_ID_TOTE}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_PROVIDES_TOTE="
-$PKG_L10N_ID_TOTE"
+$PKG_L10N_BASE_ID_TOTE"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 PKG_L10N_DESCRIPTION_TOTE_EN="$PKG_L10N_DESCRIPTION_EN"
@@ -193,10 +198,6 @@ PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_TOTE="${GAME_ID_TOTE}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID $PKG_L10N_ID"
-PKG_BIN_DEPS_TOTE="$PKG_DATA_ID_TOTE $PKG_L10N_ID_TOTE"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
