@@ -9,9 +9,9 @@ set -o errexit
 # - Emperor: Rise of the Middle Kingdom
 ###
 
-script_version=20240413.2
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_ZEUS='zeus-master-of-olympus'
 GAME_NAME_ZEUS='Zeus: Master of Olympus'
@@ -103,16 +103,18 @@ APP_EDIT_EXE='emperoredit.exe'
 APP_EDIT_ICON_EMPEROR="$APP_MAIN_ICON_EMPEROR"
 
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
+
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 
 PKG_DATA_ID_ZEUS="${GAME_ID_ZEUS}-data"
 PKG_DATA_ID_EMPEROR="${GAME_ID_EMPEROR}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS_ZEUS="$PKG_DATA_ID_ZEUS"
-PKG_BIN_DEPS_EMPEROR="$PKG_DATA_ID_EMPEROR"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
