@@ -10,9 +10,9 @@ set -o errexit
 # - Baldur's Gate 1 Enhanced Edition - Faces of Good and Evil
 ###
 
-script_version=20240416.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_DRAGONSPEAR='baldurs-gate-1-enhanced-edition'
 GAME_NAME_DRAGONSPEAR='Baldurʼs Gate Enhanced Edition'
@@ -57,8 +57,11 @@ CONTENT_GAME_MAIN_FILES_FACES='
 override/yanner2?.bmp
 override/M_YANN2.lua'
 
-PKG_MAIN_DEPS_DRAGONSPEAR="$GAME_ID_DRAGONSPEAR"
-PKG_MAIN_DEPS_FACES="$GAME_ID_FACES"
+PKG_PARENT_ID_DRAGONSPEAR="$GAME_ID_DRAGONSPEAR"
+PKG_PARENT_ID_FACES="$GAME_ID_FACES"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
