@@ -12,9 +12,9 @@ set -o errexit
 # - Planescape: Torment Enhanced Edition
 ###
 
-script_version=20240528.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_BG1='baldurs-gate-1-enhanced-edition'
 GAME_NAME_BG1='Baldurʼs Gate Enhanced Edition'
@@ -185,12 +185,10 @@ PKG_L10N_EN
 PKG_L10N_FR
 PKG_DATA'
 
-PKG_L10N_EN_DESCRIPTION='English localization'
-PKG_L10N_FR_DESCRIPTION='French localization'
-
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -205,62 +203,59 @@ libssl.so.1.0.0
 libstdc++.so.6
 libX11.so.6'
 
+PKG_L10N_EN_DESCRIPTION='English localization'
+PKG_L10N_FR_DESCRIPTION='French localization'
+
+PKG_DATA_DESCRIPTION='data'
+
 ## Baldur's Gate 1 Enhanced Edition
 
-PKG_L10N_ID_BG1="${GAME_ID_BG1}-l10n"
-PKG_L10N_EN_ID_BG1="${PKG_L10N_ID_BG1}-en"
-PKG_L10N_FR_ID_BG1="${PKG_L10N_ID_BG1}-fr"
+PKG_L10N_BASE_ID_BG1="${GAME_ID_BG1}-l10n"
+PKG_L10N_EN_ID_BG1="${PKG_L10N_BASE_ID_BG1}-en"
+PKG_L10N_FR_ID_BG1="${PKG_L10N_BASE_ID_BG1}-fr"
 PKG_L10N_PROVIDES_BG1="
-$PKG_L10N_ID_BG1"
+$PKG_L10N_BASE_ID_BG1"
 PKG_L10N_EN_PROVIDES_BG1="$PKG_L10N_PROVIDES_BG1"
 PKG_L10N_FR_PROVIDES_BG1="$PKG_L10N_PROVIDES_BG1"
 
 PKG_DATA_ID_BG1="${GAME_ID_BG1}-data"
 
-PKG_BIN_DEPS_BG1="$PKG_L10N_ID_BG1 $PKG_DATA_ID_BG1"
-
 ## Baldur's Gate 2 Enhanced Edition
 
-PKG_L10N_ID_BG2="${GAME_ID_BG2}-l10n"
-PKG_L10N_EN_ID_BG2="${PKG_L10N_ID_BG2}-en"
-PKG_L10N_FR_ID_BG2="${PKG_L10N_ID_BG2}-fr"
+PKG_L10N_BASE_ID_BG2="${GAME_ID_BG2}-l10n"
+PKG_L10N_EN_ID_BG2="${PKG_L10N_BASE_ID_BG2}-en"
+PKG_L10N_FR_ID_BG2="${PKG_L10N_BASE_ID_BG2}-fr"
 PKG_L10N_PROVIDES_BG2="
-$PKG_L10N_ID_BG2"
+$PKG_L10N_BASE_ID_BG2"
 PKG_L10N_EN_PROVIDES_BG2="$PKG_L10N_PROVIDES_BG2"
 PKG_L10N_FR_PROVIDES_BG2="$PKG_L10N_PROVIDES_BG2"
 
 PKG_DATA_ID_BG2="${GAME_ID_BG2}-data"
 
-PKG_BIN_DEPS_BG2="$PKG_L10N_ID_BG2 $PKG_DATA_ID_BG2"
-
 ## Icewind Dale 1 Enhanced Edition
 
-PKG_L10N_ID_IWD1="${GAME_ID_IWD1}-l10n"
-PKG_L10N_EN_ID_IWD1="${PKG_L10N_ID_IWD1}-en"
-PKG_L10N_FR_ID_IWD1="${PKG_L10N_ID_IWD1}-fr"
+PKG_L10N_BASE_ID_IWD1="${GAME_ID_IWD1}-l10n"
+PKG_L10N_EN_ID_IWD1="${PKG_L10N_BASE_ID_IWD1}-en"
+PKG_L10N_FR_ID_IWD1="${PKG_L10N_BASE_ID_IWD1}-fr"
 PKG_L10N_PROVIDES_IWD1="
-$PKG_L10N_ID_IWD1"
+$PKG_L10N_BASE_ID_IWD1"
 PKG_L10N_EN_PROVIDES_IWD1="$PKG_L10N_PROVIDES_IWD1"
 PKG_L10N_FR_PROVIDES_IWD1="$PKG_L10N_PROVIDES_IWD1"
 
 PKG_DATA_ID_IWD1="${GAME_ID_IWD1}-data"
 
-PKG_BIN_DEPS_IWD1="$PKG_L10N_ID_IWD1 $PKG_DATA_ID_IWD1"
-
 ## Planescape: Torment Enhanced Edition
 
-PKG_L10N_ID_PST="${GAME_ID_PST}-l10n"
-PKG_L10N_EN_ID_PST="${PKG_L10N_ID_PST}-en"
-PKG_L10N_FR_ID_PST="${PKG_L10N_ID_PST}-fr"
+PKG_L10N_BASE_ID_PST="${GAME_ID_PST}-l10n"
+PKG_L10N_EN_ID_PST="${PKG_L10N_BASE_ID_PST}-en"
+PKG_L10N_FR_ID_PST="${PKG_L10N_BASE_ID_PST}-fr"
 PKG_L10N_PROVIDES_PST="
-$PKG_L10N_ID_PST"
+$PKG_L10N_BASE_ID_PST"
 PKG_L10N_EN_PROVIDES_PST="$PKG_L10N_PROVIDES_PST"
 PKG_L10N_FR_PROVIDES_PST="$PKG_L10N_PROVIDES_PST"
 
 PKG_DATA_ID_PST="${GAME_ID_PST}-data"
 
-PKG_BIN_DEPS_PST="$PKG_L10N_ID_PST $PKG_DATA_ID_PST"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
