@@ -12,9 +12,9 @@ set -o errexit
 # - Planescape: Torment
 ###
 
-script_version=20240409.1
+script_version=20240719.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_BG1='baldurs-gate-1'
 GAME_NAME_BG1='Baldurʼs Gate'
@@ -250,7 +250,6 @@ characters
 mpsave
 save'
 
-WINE_VIRTUAL_DESKTOP='auto'
 ## Disable the multi-threaded command stream feature, as it has a very severe impact on performances.
 WINE_WINETRICKS_VERBS='csmt=off'
 
@@ -319,6 +318,11 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 PKG_L10N_DESCRIPTION_PL='Polish localization'
@@ -326,77 +330,68 @@ PKG_L10N_DESCRIPTION_RU='Russian localization'
 
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-
 ## Baldur's Gate 1
 
-PKG_L10N_ID_BG1="${GAME_ID_BG1}-l10n"
-PKG_L10N_ID_BG1_EN="${PKG_L10N_ID_BG1}-en"
-PKG_L10N_ID_BG1_FR="${PKG_L10N_ID_BG1}-fr"
-PKG_L10N_ID_BG1_PL="${PKG_L10N_ID_BG1}-pl"
+PKG_L10N_BASE_ID_BG1="${GAME_ID_BG1}-l10n"
+PKG_L10N_ID_BG1_EN="${PKG_L10N_BASE_ID_BG1}-en"
+PKG_L10N_ID_BG1_FR="${PKG_L10N_BASE_ID_BG1}-fr"
+PKG_L10N_ID_BG1_PL="${PKG_L10N_BASE_ID_BG1}-pl"
 PKG_L10N_PROVIDES_BG1="
-$PKG_L10N_ID_BG1"
+$PKG_L10N_BASE_ID_BG1"
 PKG_L10N_DESCRIPTION_BG1_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_BG1_FR="$PKG_L10N_DESCRIPTION_FR"
 PKG_L10N_DESCRIPTION_BG1_PL="$PKG_L10N_DESCRIPTION_PL"
 
 PKG_DATA_ID_BG1="${GAME_ID_BG1}-data"
 
-PKG_BIN_DEPS_BG1="$PKG_L10N_ID_BG1 $PKG_DATA_ID_BG1"
-
 ## Baldur's Gate 2
 
-PKG_L10N_ID_BG2="${GAME_ID_BG2}-l10n"
-PKG_L10N_ID_BG2_EN="${PKG_L10N_ID_BG2}-en"
-PKG_L10N_ID_BG2_FR="${PKG_L10N_ID_BG2}-fr"
+PKG_L10N_BASE_ID_BG2="${GAME_ID_BG2}-l10n"
+PKG_L10N_ID_BG2_EN="${PKG_L10N_BASE_ID_BG2}-en"
+PKG_L10N_ID_BG2_FR="${PKG_L10N_BASE_ID_BG2}-fr"
 PKG_L10N_PROVIDES_BG2="
-$PKG_L10N_ID_BG2"
+$PKG_L10N_BASE_ID_BG2"
 PKG_L10N_DESCRIPTION_BG2_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_BG2_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_BG2="${GAME_ID_BG2}-data"
 
-PKG_BIN_DEPS_BG2="$PKG_L10N_ID_BG2 $PKG_DATA_ID_BG2"
-
 ## Icewind Dale 1
 
-PKG_L10N_ID_IWD1="${GAME_ID_IWD1}-l10n-en"
+PKG_L10N_BASE_ID_IWD1="${GAME_ID_IWD1}-l10n"
+PKG_L10N_ID_IWD1="${PKG_L10N_BASE_ID_IWD1}-en"
+PKG_L10N_PROVIDES_IWD1="
+$PKG_L10N_BASE_ID_IWD1"
 PKG_L10N_DESCRIPTION_IWD1="$PKG_L10N_DESCRIPTION_EN"
 
 PKG_DATA_ID_IWD1="${GAME_ID_IWD1}-data"
 
-PKG_BIN_DEPS_IWD1="$PKG_L10N_ID_IWD1 $PKG_DATA_ID_IWD1"
-
 ## Icewind Dale 2
 
-PKG_L10N_ID_IWD2="${GAME_ID_IWD2}-l10n"
-PKG_L10N_ID_IWD2_EN="${PKG_L10N_ID_IWD2}-en"
-PKG_L10N_ID_IWD2_FR="${PKG_L10N_ID_IWD2}-fr"
+PKG_L10N_BASE_ID_IWD2="${GAME_ID_IWD2}-l10n"
+PKG_L10N_ID_IWD2_EN="${PKG_L10N_BASE_ID_IWD2}-en"
+PKG_L10N_ID_IWD2_FR="${PKG_L10N_BASE_ID_IWD2}-fr"
 PKG_L10N_PROVIDES_IWD2="
-$PKG_L10N_ID_IWD2"
+$PKG_L10N_BASE_ID_IWD2"
 PKG_L10N_DESCRIPTION_IWD2_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_IWD2_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_IWD2="${GAME_ID_IWD2}-data"
 
-PKG_BIN_DEPS_IWD2="$PKG_L10N_ID_IWD2 $PKG_DATA_ID_IWD2"
-
 ## Planescape: Torment
 
-PKG_L10N_ID_PST="${GAME_ID_PST}-l10n"
-PKG_L10N_ID_PST_EN="${PKG_L10N_ID_PST}-en"
-PKG_L10N_ID_PST_FR="${PKG_L10N_ID_PST}-fr"
-PKG_L10N_ID_PST_RU="${PKG_L10N_ID_PST}-ru"
+PKG_L10N_BASE_ID_PST="${GAME_ID_PST}-l10n"
+PKG_L10N_ID_PST_EN="${PKG_L10N_BASE_ID_PST}-en"
+PKG_L10N_ID_PST_FR="${PKG_L10N_BASE_ID_PST}-fr"
+PKG_L10N_ID_PST_RU="${PKG_L10N_BASE_ID_PST}-ru"
 PKG_L10N_PROVIDES_PST="
-$PKG_L10N_ID_PST"
+$PKG_L10N_BASE_ID_PST"
 PKG_L10N_DESCRIPTION_PST_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_PST_FR="$PKG_L10N_DESCRIPTION_FR"
 PKG_L10N_DESCRIPTION_PST_RU="$PKG_L10N_DESCRIPTION_RU"
 
 PKG_DATA_ID_PST="${GAME_ID_PST}-data"
 
-PKG_BIN_DEPS_PST="$PKG_L10N_ID_PST $PKG_DATA_ID_PST"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -534,6 +529,9 @@ archive_extraction_default
 			EOF
 		;;
 	esac
+	## The native windowed mode is used instead of a WINE virtual desktop,
+	## as using a WINE virtual desktop would cause cursor flickering (WINE 9.0).
+	## cf. https://bugs.winehq.org/show_bug.cgi?id=56986
 	cat >> "$config_file" <<- EOF
 	[Program Options]
 	Full Screen=0
