@@ -7,16 +7,16 @@ set -o errexit
 # Ironclad Tactics
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='ironclad-tactics'
 GAME_NAME='Ironclad Tactics'
 
 ARCHIVE_BASE_0_NAME='gog_ironclad_tactics_deluxe_edition_2.0.0.4.sh'
 ARCHIVE_BASE_0_MD5='a0a0e2195364e57bc39e180d442e1f6b'
-ARCHIVE_BASE_0_SIZE='960000'
+ARCHIVE_BASE_0_SIZE='953272'
 ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.4'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/ironclad_tactics_deluxe_edition'
 
@@ -55,11 +55,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -71,6 +69,9 @@ libSDL2-2.0.so.0
 libSDL2_mixer-2.0.so.0
 libstdc++.so.6'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -96,11 +97,6 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Apply common Mono tweaks
-
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-$(mono_launcher_tweaks)"
-
 # Extract game data
 
 archive_extraction_default
@@ -112,6 +108,10 @@ content_inclusion_default
 
 # Write launchers
 
+## Apply common Mono tweaks.
+APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
+$(mono_launcher_tweaks)"
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
