@@ -7,9 +7,9 @@ set -o errexit
 # Jade Empire
 ###
 
-script_version=20240420.2
+script_version=20240720.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='jade-empire'
 GAME_NAME='Jade Empire'
@@ -23,7 +23,7 @@ ARCHIVE_BASE_EN_1_PART1_TYPE='innosetup'
 ARCHIVE_BASE_EN_1_PART2_NAME='setup_jade_empire_1.00_(15538)-2.bin'
 ARCHIVE_BASE_EN_1_PART2_MD5='57f4931e55373a9c994b67d14f43dc1c'
 ARCHIVE_BASE_EN_1_PART2_TYPE='innosetup'
-ARCHIVE_BASE_EN_1_SIZE='7600000'
+ARCHIVE_BASE_EN_1_SIZE='7454315'
 ARCHIVE_BASE_EN_1_VERSION='1.00-gog15538'
 ARCHIVE_BASE_EN_1_URL='https://www.gog.com/game/jade_empire_special_edition'
 
@@ -36,7 +36,7 @@ ARCHIVE_BASE_FR_1_PART1_TYPE='innosetup'
 ARCHIVE_BASE_FR_1_PART2_NAME='setup_jade_empire_french_1.00_(15538)-2.bin'
 ARCHIVE_BASE_FR_1_PART2_MD5='428bf4eba51fde69fa6fe6fb05aadb96'
 ARCHIVE_BASE_FR_1_PART2_TYPE='innosetup'
-ARCHIVE_BASE_FR_1_SIZE='7700000'
+ARCHIVE_BASE_FR_1_SIZE='7608886'
 ARCHIVE_BASE_FR_1_VERSION='1.00-gog15538'
 ARCHIVE_BASE_FR_1_URL='https://www.gog.com/game/jade_empire_special_edition'
 
@@ -63,8 +63,14 @@ ARCHIVE_BASE_EN_0_VERSION='1.0-gog2.0.0.4'
 
 CONTENT_PATH_DEFAULT='app'
 CONTENT_GAME_BIN_FILES='
-*.dll
-*.exe'
+binkw32.dll
+d3d9.dll
+ogg.dll
+vorbis.dll
+vorbisfile.dll
+jadeempire.exe
+jadeempireconfig.exe
+jadeempirelauncher.exe'
 CONTENT_GAME_L10N_FILES='
 sound
 data/bips
@@ -128,20 +134,22 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
