@@ -7,9 +7,9 @@ set -o errexit
 # Jazz Jackrabbit 2
 ###
 
-script_version=20240430.5
+script_version=20240605.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='jazz-jackrabbit-2'
 GAME_NAME='Jazz Jackrabbit 2'
@@ -125,15 +125,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_ID_JJ2PLUS="${GAME_ID_JJ2PLUS}-data"
-PKG_DATA_ID_CHRISTMAS="${GAME_ID_CHRISTMAS}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN_DEPS_JJ2PLUS="$PKG_DATA_ID_JJ2PLUS"
-PKG_BIN_DEPS_CHRISTMAS="$PKG_DATA_ID_CHRISTMAS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
@@ -173,6 +167,11 @@ jazz-jackrabbit-2-the-christmas-chronicles-bin"
 PKG_BIN_PROVIDES_JJ2PLUS="${PKG_BIN_PROVIDES_JJ2PLUS:-}
 jazz-jackrabbit-2-jj2plus-bin"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_ID_JJ2PLUS="${GAME_ID_JJ2PLUS}-data"
+PKG_DATA_ID_CHRISTMAS="${GAME_ID_CHRISTMAS}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
