@@ -8,9 +8,9 @@ set -o errexit
 # - Ho Ho Holiday
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='little-inferno'
 GAME_NAME='Little Inferno'
@@ -24,7 +24,7 @@ EXPANSION_NAME_HOHOHOLIDAY='Ho Ho Holiday'
 
 ARCHIVE_BASE_HOHOHOLIDAY_0_NAME='LittleInfernoHoHoHoliday-Linux-2022-12-07.sh'
 ARCHIVE_BASE_HOHOHOLIDAY_0_MD5='7124105953b1a899f239a0fdbd492458'
-ARCHIVE_BASE_HOHOHOLIDAY_0_SIZE='430'
+ARCHIVE_BASE_HOHOHOLIDAY_0_SIZE='381'
 ARCHIVE_BASE_HOHOHOLIDAY_0_VERSION='1.0-humble.2022.12.07'
 ARCHIVE_BASE_HOHOHOLIDAY_0_URL='http://tomorrowcorporation.com/littleinferno#hohoholiday'
 
@@ -33,7 +33,10 @@ CONTENT_PATH_DEFAULT='data/noarch'
 CONTENT_GAME_MAIN_FILES='
 .tcgame-4097.info'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
