@@ -8,16 +8,16 @@ set -o errexit
 # Little Inferno
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='little-inferno'
 GAME_NAME='Little Inferno'
 
 ARCHIVE_BASE_HUMBLE_1_NAME='LittleInferno_Linux_v2.0.3.sh'
 ARCHIVE_BASE_HUMBLE_1_MD5='2d104de7966405f905d36bfbc7722808'
-ARCHIVE_BASE_HUMBLE_1_SIZE='280000'
+ARCHIVE_BASE_HUMBLE_1_SIZE='274737'
 ARCHIVE_BASE_HUMBLE_1_VERSION='2.0.3-humble.2022.12.08'
 ARCHIVE_BASE_HUMBLE_1_URL='https://www.humblebundle.com/store/little-inferno'
 
@@ -81,14 +81,12 @@ PACKAGES_LIST_GOG='
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
@@ -112,13 +110,16 @@ libstdc++.so.6
 libvorbis.so.0
 libX11.so.6'
 ## Include shipped libvorbis.so.0 for game build 1.x, the game segfaults when using a system-provided library instead.
-PKG_BIN32_DEPENDENCIES_LIBRARIES_OLD="${PKG_BIN32_DEPENDENCIES_LIBRARIES_OLD:-}
+PKG_BIN_DEPENDENCIES_LIBRARIES_OLD="${PKG_BIN_DEPENDENCIES_LIBRARIES_OLD:-}
 libc.so.6
 libm.so.6
 libogg.so.0"
 PKG_BIN32_DEPENDENCIES_LIBRARIES_HUMBLE_0="$PKG_BIN_DEPENDENCIES_LIBRARIES_OLD"
 PKG_BIN32_DEPENDENCIES_LIBRARIES_GOG="$PKG_BIN_DEPENDENCIES_LIBRARIES_OLD"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
