@@ -7,9 +7,9 @@ set -o errexit
 # Loop Hero
 ###
 
-script_version=20240408.1
+script_version=20240605.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='loop-hero'
 GAME_NAME='Loop Hero'
@@ -61,6 +61,18 @@ assets/fonts
 assets/local'
 
 APP_MAIN_EXE='Loop_Hero'
+## The demo crashes on launch.
+## Thread 1 "LooPatHerO" received signal SIGFPE, Arithmetic exception.
+## gdb trace:
+## #0  0x000000000064bf80 in ?? ()
+## #1  0x000000000064be69 in ?? ()
+## #2  0x000000000064b80f in ?? ()
+## #3  0x000000000072db2e in ?? ()
+## #4  0x0000000000744415 in ?? ()
+## #5  0x00000000005ad6da in ?? ()
+## #6  0x00007ffff6efcc8a in __libc_start_call_main (main=main@entry=0x5acfc0, argc=argc@entry=1, argv=argv@entry=0x7fffffffde38) at ../sysdeps/nptl/libc_start_call_main.h:58
+## #7  0x00007ffff6efcd45 in __libc_start_main_impl (main=0x5acfc0, argc=1, argv=0x7fffffffde38, init=<optimized out>, fini=<optimized out>, rtld_fini=<optimized out>, stack_end=0x7fffffffde28) at ../csu/libc-start.c:360
+## #8  0x00000000004098ea in ?? ()
 APP_MAIN_EXE_DEMO='LooPatHerO'
 APP_MAIN_ICON='assets/icon.png'
 ## Work around broken support for non-US locales.
@@ -72,15 +84,11 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ID="$GAME_ID"
 PKG_BIN_ID_DEMO="$GAME_ID_DEMO"
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libcurl.so.4
@@ -100,6 +108,10 @@ libXrandr.so.2
 libXxf86vm.so.1
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
