@@ -8,9 +8,9 @@ set -o errexit
 # - The Murder Crow
 ###
 
-script_version=20240127.1
+script_version=20240530.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='mask-of-the-rose'
 GAME_NAME='Mask of the Rose'
@@ -22,6 +22,11 @@ EXPANSION_NAME_CROW='The Murder Crow'
 
 ## The Murder Crow
 
+ARCHIVE_BASE_CROW_5_NAME='mask_of_the_rose_the_murder_crow_1_6_1043_linux_70837.sh'
+ARCHIVE_BASE_CROW_5_MD5='1e492aad8f1b246055c485c924fb607b'
+ARCHIVE_BASE_CROW_5_SIZE='999'
+ARCHIVE_BASE_CROW_5_VERSION='1.6.1043-gog70837'
+
 ARCHIVE_BASE_CROW_4_NAME='mask_of_the_rose_the_murder_crow_1_6_1024_linux_70649.sh'
 ARCHIVE_BASE_CROW_4_MD5='f6b9cd36e7c57a775170d6953eeff7e2'
 ARCHIVE_BASE_CROW_4_SIZE='999'
