@@ -8,9 +8,9 @@ set -o errexit
 # Mask of the Rose
 ###
 
-script_version=20240127.1
+script_version=20240530.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='mask-of-the-rose'
 GAME_NAME='Mask of the Rose'
@@ -22,11 +22,16 @@ GAME_NAME_DEMO="$GAME_NAME (demo)"
 
 ## Full game
 
+ARCHIVE_BASE_5_NAME='mask_of_the_rose_1_6_1043_linux_70837.sh'
+ARCHIVE_BASE_5_MD5='f7fc5f6adb0621cc0c3560658de3f372'
+ARCHIVE_BASE_5_SIZE='2674740'
+ARCHIVE_BASE_5_VERSION='1.6.1043-gog70837'
+ARCHIVE_BASE_5_URL='https://www.gog.com/game/mask_of_the_rose'
+
 ARCHIVE_BASE_4_NAME='mask_of_the_rose_1_6_1024_linux_70649.sh'
 ARCHIVE_BASE_4_MD5='6342815fe4de7b9e2998d6563e27ec6f'
 ARCHIVE_BASE_4_SIZE='2674723'
 ARCHIVE_BASE_4_VERSION='1.6.1024-gog70649'
-ARCHIVE_BASE_4_URL='https://www.gog.com/game/mask_of_the_rose'
 
 ARCHIVE_BASE_3_NAME='mask_of_the_rose_1_5_943_linux_68850.sh'
 ARCHIVE_BASE_3_MD5='950ad3b9a759c4c21fd31b155cb85f2c'
@@ -115,14 +120,12 @@ archive_extraction_default
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
