@@ -8,9 +8,9 @@ set -o errexit
 # Monkey Island 4
 ###
 
-script_version=20240408.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='monkey-island-4'
 GAME_NAME='Monkey Island 4: Escape from Monkey Island'
@@ -100,41 +100,46 @@ PKG_BIN_WINE
 PKG_L10N
 PKG_DATA'
 
+PKG_BIN_BASE_ID="$GAME_ID"
+PKG_BIN_PROVIDES="
+$PKG_BIN_BASE_ID"
+## A dependency on the language-specific variant of the localization package is set,
+## not on the common name provided by both variants of this package.
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
-PKG_BIN_ID="$GAME_ID"
-PKG_BIN_PROVIDES="
-$PKG_BIN_ID"
-
 ## ScummVM
 
-PKG_BIN_SCUMMVM_ID="${PKG_BIN_ID}-scummvm"
-PKG_BIN_SCUMMVM_ID_EN="${PKG_BIN_SCUMMVM_ID}-en"
-PKG_BIN_SCUMMVM_ID_FR="${PKG_BIN_SCUMMVM_ID}-fr"
-PKG_BIN_SCUMMVM_PROVIDES="$PKG_BIN_PROVIDES"
+PKG_BIN_SCUMMVM_BASE_ID="${PKG_BIN_BASE_ID}-scummvm"
+PKG_BIN_SCUMMVM_ID_EN="${PKG_BIN_SCUMMVM_BASE_ID}-en"
+PKG_BIN_SCUMMVM_ID_FR="${PKG_BIN_SCUMMVM_BASE_ID}-fr"
+PKG_BIN_SCUMMVM_PROVIDES="$PKG_BIN_BASE_PROVIDES"
 PKG_BIN_SCUMMVM_DESCRIPTION_EN='English version'
 PKG_BIN_SCUMMVM_DESCRIPTION_FR='French version'
-PKG_BIN_SCUMMVM_DEPS="$PKG_DATA_ID"
+PKG_BIN_SCUMMVM_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 
 ## WINE
 
 PKG_BIN_WINE_ARCH='32'
-PKG_BIN_WINE_ID="${PKG_BIN_ID}-wine"
-PKG_BIN_WINE_ID_EN="${PKG_BIN_WINE_ID}-en"
-PKG_BIN_WINE_ID_FR="${PKG_BIN_WINE_ID}-fr"
+PKG_BIN_WINE_BASE_ID="${PKG_BIN_BASE_ID}-wine"
+PKG_BIN_WINE_ID_EN="${PKG_BIN_WINE_BASE_ID}-en"
+PKG_BIN_WINE_ID_FR="${PKG_BIN_WINE_BASE_ID}-fr"
 PKG_BIN_WINE_PROVIDES="$PKG_BIN_PROVIDES"
 PKG_BIN_WINE_DESCRIPTION_EN='English version'
 PKG_BIN_WINE_DESCRIPTION_FR='French version'
-PKG_BIN_WINE_DEPS="$PKG_DATA_ID $PKG_L10N_ID"
+PKG_BIN_WINE_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 
 # WINE - Register install path
 
