@@ -7,9 +7,9 @@ set -o errexit
 # Off-World Resource Base
 ###
 
-script_version=20240417.1
+script_version=20240720.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='off-world-resource-base'
 GAME_NAME='O.R.B.: Off-World Resource Base'
@@ -17,7 +17,7 @@ GAME_NAME='O.R.B.: Off-World Resource Base'
 ARCHIVE_BASE_0_NAME='setup_orb_2.0.0.5.exe'
 ARCHIVE_BASE_0_MD5='b1cab44f6fe398ed008dda23e1538c03'
 ARCHIVE_BASE_0_TYPE='innosetup'
-ARCHIVE_BASE_0_SIZE='660000'
+ARCHIVE_BASE_0_SIZE='651435'
 ARCHIVE_BASE_0_VERSION='1.04-gog2.0.0.5'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/orb_offworld_resource_base'
 
@@ -79,12 +79,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
