@@ -7,9 +7,9 @@ set -o errexit
 # Oil Rush
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='oil-rush'
 GAME_NAME='Oil Rush'
@@ -17,8 +17,8 @@ GAME_NAME='Oil Rush'
 ## This archive used to be provided by Humble Bundle, but it is no longer available for sale.
 ARCHIVE_BASE_0_NAME='OilRush_1.35_Linux_1370041755.run'
 ARCHIVE_BASE_0_MD5='5a38d0545a64e0d21ddfe4afc15253a8'
+ARCHIVE_BASE_0_SIZE='1351677'
 ARCHIVE_BASE_0_VERSION='1.35-humble1'
-ARCHIVE_BASE_0_SIZE='1400000'
 
 CONTENT_PATH_DEFAULT='.'
 CONTENT_LIBS_BIN64_PATH="${CONTENT_PATH_DEFAULT}/bin"
@@ -63,7 +63,7 @@ APP_MAIN_EXE_BIN32='bin/launcher_x86'
 APP_MAIN_OPTIONS='-config ../data/launcher/launcher.xml'
 APP_MAIN_ICON='data/launcher/oilrush.png'
 ## Run the game binary from its parent directory
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # Run the game binary from its parent directory
 cd "$(dirname "$APP_EXE")"
 APP_EXE=$(basename "$APP_EXE")
@@ -74,14 +74,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -100,6 +98,9 @@ libXrender.so.1'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -145,38 +146,37 @@ content_inclusion_default
 ## Copy the real game binary into the game prefix.
 ## (bin/OilRush_x64 instead of bin/launcher_x64)
 native_launcher_binary_copy() {
-	{
-		cat <<- 'EOF'
-		# Copy the game binary into the user prefix
+	cat <<- 'EOF'
+	# Copy the game binary into the user prefix
 
-		exe_destination="${PATH_PREFIX}/bin/OilRush_x64"
-		if [ -h "$exe_destination" ]; then
-		    exe_source=$(realpath "$exe_destination")
-		    cp --remove-destination "$exe_source" "$exe_destination"
-		fi
-		unset exe_destination exe_source
+	exe_destination="${PATH_PREFIX}/bin/OilRush_x64"
+	if [ -h "$exe_destination" ]; then
+	    exe_source=$(realpath "$exe_destination")
+	    cp --remove-destination "$exe_source" "$exe_destination"
+	fi
+	unset exe_destination exe_source
 
-		EOF
-	} | sed --regexp-extended 's/( ){4}/\t/g'
+	EOF
 }
+
 launchers_generation 'PKG_BIN64'
+
 ## Copy the real game binary into the game prefix.
 ## (bin/OilRush_x86 instead of bin/launcher_x86)
 native_launcher_binary_copy() {
-	{
-		cat <<- 'EOF'
-		# Copy the game binary into the user prefix
+	cat <<- 'EOF'
+	# Copy the game binary into the user prefix
 
-		exe_destination="${PATH_PREFIX}/bin/OilRush_x86"
-		if [ -h "$exe_destination" ]; then
-		    exe_source=$(realpath "$exe_destination")
-		    cp --remove-destination "$exe_source" "$exe_destination"
-		fi
-		unset exe_destination exe_source
+	exe_destination="${PATH_PREFIX}/bin/OilRush_x86"
+	if [ -h "$exe_destination" ]; then
+	    exe_source=$(realpath "$exe_destination")
+	    cp --remove-destination "$exe_source" "$exe_destination"
+	fi
+	unset exe_destination exe_source
 
-		EOF
-	} | sed --regexp-extended 's/( ){4}/\t/g'
+	EOF
 }
+
 launchers_generation 'PKG_BIN32'
 
 # Build packages
