@@ -7,9 +7,9 @@ set -o errexit
 # Painkiller
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='painkiller'
 GAME_NAME='Painkiller'
@@ -19,7 +19,7 @@ ARCHIVE_BASE_EN_0_MD5='328381c6d874b5c6822cdcf596b6c00e'
 ARCHIVE_BASE_EN_0_TYPE='innosetup'
 ARCHIVE_BASE_EN_0_PART1_NAME='setup_painkiller_black_1.64_lang_update_(24538)-1.bin'
 ARCHIVE_BASE_EN_0_PART1_MD5='26cf8f833c5b75efb006eac0e731a0af'
-ARCHIVE_BASE_EN_0_SIZE='4000000'
+ARCHIVE_BASE_EN_0_SIZE='3934610'
 ARCHIVE_BASE_EN_0_VERSION='1.6.4-gog24538'
 ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/painkiller'
 
@@ -28,7 +28,7 @@ ARCHIVE_BASE_FR_0_MD5='9a4301af374c500ac7d00b5e7ad70b65'
 ARCHIVE_BASE_FR_0_TYPE='innosetup'
 ARCHIVE_BASE_FR_0_PART1_NAME='setup_painkiller_black_1.64_lang_update_(french)_(24538)-1.bin'
 ARCHIVE_BASE_FR_0_PART1_MD5='09e9614cadf2973ead1f826c24ebf2fe'
-ARCHIVE_BASE_FR_0_SIZE='3700000'
+ARCHIVE_BASE_FR_0_SIZE='3612122'
 ARCHIVE_BASE_FR_0_VERSION='1.6.0-gog24538'
 ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/painkiller'
 
@@ -63,6 +63,11 @@ PKG_BIN
 PKG_MOVIES
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_MOVIES
+PKG_DATA'
+
 PKG_MOVIES_ID="${GAME_ID}-movies"
 PKG_MOVIES_ID_EN="${PKG_MOVIES_ID}-en"
 PKG_MOVIES_ID_FR="${PKG_MOVIES_ID}-fr"
@@ -74,9 +79,6 @@ PKG_MOVIES_DESCRIPTION_FR='French movies'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_MOVIES_ID $PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
