@@ -13,9 +13,9 @@ set -o errexit
 # - Deadfire Pack
 ###
 
-script_version=20240411.1
+script_version=20240717.4
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='pillars-of-eternity-1'
 GAME_NAME='Pillars of Eternity'
@@ -44,28 +44,28 @@ EXPANSION_NAME_DEADFIRE='Deadfire Pack'
 
 ARCHIVE_BASE_TIER1BACKER_0_NAME='gog_pillars_of_eternity_kickstarter_item_dlc_2.0.0.2.sh'
 ARCHIVE_BASE_TIER1BACKER_0_MD5='b4c29ae17c87956471f2d76d8931a4e5'
-ARCHIVE_BASE_TIER1BACKER_0_SIZE='1300'
+ARCHIVE_BASE_TIER1BACKER_0_SIZE='924'
 ARCHIVE_BASE_TIER1BACKER_0_VERSION='1.0-gog2.0.0.2'
 
 ## Kickstarter pet
 
 ARCHIVE_BASE_TIER2BACKER_0_NAME='gog_pillars_of_eternity_kickstarter_pet_dlc_2.0.0.2.sh'
 ARCHIVE_BASE_TIER2BACKER_0_MD5='3653fc2a98ef578335f89b607f0b7968'
-ARCHIVE_BASE_TIER2BACKER_0_SIZE='1300'
+ARCHIVE_BASE_TIER2BACKER_0_SIZE='924'
 ARCHIVE_BASE_TIER2BACKER_0_VERSION='1.0-gog2.0.0.2'
 
 ## Pre-order item and pet
 
 ARCHIVE_BASE_PREORDER_0_NAME='gog_pillars_of_eternity_preorder_item_and_pet_dlc_2.0.0.2.sh'
 ARCHIVE_BASE_PREORDER_0_MD5='b86ad866acb62937d2127407e4beab19'
-ARCHIVE_BASE_PREORDER_0_SIZE='1300'
+ARCHIVE_BASE_PREORDER_0_SIZE='924'
 ARCHIVE_BASE_PREORDER_0_VERSION='1.0-gog2.0.0.2'
 
 ## The White March, Part 1
 
 ARCHIVE_BASE_TWM1_3_NAME='pillars_of_eternity_white_march_part_1_dlc_en_3_07_0_1318_17464.sh'
 ARCHIVE_BASE_TWM1_3_MD5='cc72f59ee20238ff05c47646b4618f01'
-ARCHIVE_BASE_TWM1_3_SIZE='5600000'
+ARCHIVE_BASE_TWM1_3_SIZE='5507108'
 ARCHIVE_BASE_TWM1_3_VERSION='3.7.0.1318-gog17464'
 ARCHIVE_BASE_TWM1_3_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_1'
 
@@ -88,7 +88,7 @@ ARCHIVE_BASE_TWM1_0_VERSION='3.05.0.1186-gog2.9.0.11'
 
 ARCHIVE_BASE_TWM2_3_NAME='pillars_of_eternity_white_march_part_2_dlc_en_3_07_0_1318_17464.sh'
 ARCHIVE_BASE_TWM2_3_MD5='03067ebdd878cc16c283f63ddf015e90'
-ARCHIVE_BASE_TWM2_3_SIZE='4400000'
+ARCHIVE_BASE_TWM2_3_SIZE='4360158'
 ARCHIVE_BASE_TWM2_3_VERSION='3.7.0.1318-gog17464'
 ARCHIVE_BASE_TWM2_3_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_2'
 
@@ -111,7 +111,7 @@ ARCHIVE_BASE_TWM2_0_VERSION='3.05.1186-gog2.5.0.6'
 
 ARCHIVE_BASE_DEADFIRE_2_NAME='pillars_of_eternity_deadfire_pack_dlc_en_3_07_0_1318_20099.sh'
 ARCHIVE_BASE_DEADFIRE_2_MD5='da315aba26784e55aa51139cebb7f9d2'
-ARCHIVE_BASE_DEADFIRE_2_SIZE='1300'
+ARCHIVE_BASE_DEADFIRE_2_SIZE='922'
 ARCHIVE_BASE_DEADFIRE_2_VERSION='3.07.0.1318-gog20099'
 ARCHIVE_BASE_DEADFIRE_2_URL='https://www.gog.com/game/pillars_of_eternity_deadfire_pack'
 
@@ -130,8 +130,13 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 PillarsOfEternity_Data'
 
-PKG_MAIN_DEPS="$GAME_ID"
-PKG_MAIN_DEPS_TWM2="${PKG_MAIN_DEPS:-} ${GAME_ID}-${EXPANSION_ID_TWM1}"
+PKG_PARENT_ID="$GAME_ID"
+PKG_TWM1_ID="${GAME_ID}-${EXPANSION_ID_TWM1}"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
+PKG_MAIN_DEPENDENCIES_SIBLINGS_TWM2="$PKG_MAIN_DEPENDENCIES_SIBLINGS
+PKG_TWM1"
 
 # Load common functions
 
