@@ -8,16 +8,16 @@ set -o errexit
 # Pillars of Eternity 1
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='pillars-of-eternity-1'
 GAME_NAME='Pillars of Eternity'
 
 ARCHIVE_BASE_3_NAME='pillars_of_eternity_en_3_07_0_1318_17461.sh'
 ARCHIVE_BASE_3_MD5='57164ad0cbc53d188dde0b38e7491916'
-ARCHIVE_BASE_3_SIZE='15000000'
+ARCHIVE_BASE_3_SIZE='14801525'
 ARCHIVE_BASE_3_VERSION='3.7.0.1318-gog17461'
 ARCHIVE_BASE_3_URL='https://www.gog.com/game/pillars_of_eternity_hero_edition'
 
@@ -49,15 +49,9 @@ PKG_BIN
 PKG_DATA_AREAS
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
-PKG_DATA_AREAS_ID="${PKG_DATA_ID}-areas"
-PKG_DATA_AREAS_DESCRIPTION='areas'
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_AREAS_ID"
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -75,6 +69,14 @@ libstdc++.so.6
 libX11.so.6
 libXcursor.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_AREAS'
+
+PKG_DATA_AREAS_ID="${PKG_DATA_ID}-areas"
+PKG_DATA_AREAS_DESCRIPTION='areas'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
