@@ -7,22 +7,22 @@ set -o errexit
 # Pyre
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='pyre'
 GAME_NAME='Pyre'
 
 ARCHIVE_BASE_ITCH_1_NAME='pyre-linux.zip'
 ARCHIVE_BASE_ITCH_1_MD5='44e0fe30a9d8bcf73c4fa288dd4324ab'
-ARCHIVE_BASE_ITCH_1_SIZE='8100000'
+ARCHIVE_BASE_ITCH_1_SIZE='8051755'
 ARCHIVE_BASE_ITCH_1_VERSION='1.50476-itch.2019.03.19'
 ARCHIVE_BASE_ITCH_1_URL='https://supergiant-games.itch.io/pyre'
 
 ARCHIVE_BASE_GOG_1_NAME='pyre_1_50427_11957_23366.sh'
 ARCHIVE_BASE_GOG_1_MD5='ae34d8b4c069ffd7a98f295af4596e1f'
-ARCHIVE_BASE_GOG_1_SIZE='8200000'
+ARCHIVE_BASE_GOG_1_SIZE='8104850'
 ARCHIVE_BASE_GOG_1_VERSION='1.50427-gog23366'
 ARCHIVE_BASE_GOG_1_URL='https://www.gog.com/game/pyre'
 
@@ -77,14 +77,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -102,6 +100,9 @@ libz.so.1'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -127,11 +128,6 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Apply common Mono tweaks
-
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-$(mono_launcher_tweaks)"
-
 # Extract game data
 
 archive_extraction_default
@@ -143,6 +139,10 @@ content_inclusion_default
 
 # Write launchers
 
+## Apply common Mono tweaks.
+APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
+$(mono_launcher_tweaks)"
+
 launchers_generation 'PKG_BIN64'
 launchers_generation 'PKG_BIN32'
 
