@@ -7,17 +7,17 @@ set -o errexit
 # Rayman 1
 ###
 
-script_version=20240411.1
+script_version=20240724.1
 
 GAME_ID='rayman-1'
 GAME_NAME='Rayman'
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 ARCHIVE_BASE_1_NAME='setup_rayman_forever_1.21_(28045).exe'
 ARCHIVE_BASE_1_MD5='304cca5f14923730c76bb61f669be575'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_SIZE='290000'
+ARCHIVE_BASE_1_SIZE='279703'
 ARCHIVE_BASE_1_VERSION='1.21-gog28045'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/rayman_forever'
 
@@ -51,13 +51,16 @@ APP_MAIN_OPTIONS='save=C:\RAYMAN'
 APP_MAIN_ICON='GOGGAME-1207658919.ICO'
 APP_MAIN_ICON_0='GFW_HIGH.ICO'
 ## Run the game binary from its parent directory.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN}"'
+APP_MAIN_PRERUN='
 # Run the game binary from its parent directory
 APP_EXE_DIRECTORY=$(dirname "$APP_EXE")
 APP_EXE=$(basename "$APP_EXE")
 '
-APP_MAIN_DOSBOX_PRERUN="${APP_MAIN_DOSBOX_PRERUN:-}"'
+APP_MAIN_DOSBOX_PRERUN='
 cd $APP_EXE_DIRECTORY'
+## Use fixed cpu cycles, to improve performances.
+APP_MAIN_DOSBOX_PRERUN="${APP_MAIN_DOSBOX_PRERUN:-}
+config -set cpu cycles=fixed 80000"
 
 APP_FAN_ID="${GAME_ID}-rayfan"
 APP_FAN_NAME="$GAME_NAME - Rayman by his Fans"
@@ -65,8 +68,16 @@ APP_FAN_EXE='RAYFAN/RAYFAN.EXE'
 APP_FAN_OPTIONS='ver=usa'
 APP_FAN_ICON='RAYFAN/RAYFAN.ICO'
 ## Run the game binary from its parent directory.
-APP_FAN_PRERUN="$APP_MAIN_PRERUN"
-APP_FAN_DOSBOX_PRERUN="$APP_MAIN_DOSBOX_PRERUN"
+APP_FAN_PRERUN='
+# Run the game binary from its parent directory
+APP_EXE_DIRECTORY=$(dirname "$APP_EXE")
+APP_EXE=$(basename "$APP_EXE")
+'
+APP_FAN_DOSBOX_PRERUN='
+cd $APP_EXE_DIRECTORY'
+## Use fixed cpu cycles, to improve performances.
+APP_FAN_DOSBOX_PRERUN="${APP_FAN_DOSBOX_PRERUN:-}
+config -set cpu cycles=fixed 20000"
 
 APP_KIT_ID="${GAME_ID}-raykit"
 APP_KIT_NAME="$GAME_NAME - Rayman Designer"
@@ -74,8 +85,16 @@ APP_KIT_EXE='RAYKIT/RAYKIT.EXE'
 APP_KIT_OPTIONS='ver=usa'
 APP_KIT_ICON='RAYKIT/RAYKIT.ICO'
 ## Run the game binary from its parent directory.
-APP_KIT_PRERUN="$APP_MAIN_PRERUN"
-APP_KIT_DOSBOX_PRERUN="$APP_MAIN_DOSBOX_PRERUN"
+APP_KIT_PRERUN='
+# Run the game binary from its parent directory
+APP_EXE_DIRECTORY=$(dirname "$APP_EXE")
+APP_EXE=$(basename "$APP_EXE")
+'
+APP_KIT_DOSBOX_PRERUN='
+cd $APP_EXE_DIRECTORY'
+## Use fixed cpu cycles, to improve performances.
+APP_KIT_DOSBOX_PRERUN="${APP_KIT_DOSBOX_PRERUN:-}
+config -set cpu cycles=fixed 20000"
 
 # Load common functions
 
