@@ -9,9 +9,9 @@ set -o errexit
 # - The Emperor's Challenge
 ###
 
-script_version=20240411.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='renowned-explorers'
 GAME_NAME='Renowned Explorers'
@@ -28,7 +28,7 @@ EXPANSION_NAME_EMPERORSCHALLENGE='The Emperorʼs Challenge'
 
 ARCHIVE_BASE_MORETOEXPLORE_7_NAME='renowned_explorers_international_society_more_to_explore_dlc_522_26056.sh'
 ARCHIVE_BASE_MORETOEXPLORE_7_MD5='46b6534ff70a9efa4fc21b2ba139b52f'
-ARCHIVE_BASE_MORETOEXPLORE_7_SIZE='69000'
+ARCHIVE_BASE_MORETOEXPLORE_7_SIZE='68263'
 ARCHIVE_BASE_MORETOEXPLORE_7_VERSION='522-gog26056'
 ARCHIVE_BASE_MORETOEXPLORE_7_URL='https://www.gog.com/game/renowned_explorers_more_to_explore'
 
@@ -71,7 +71,7 @@ ARCHIVE_BASE_MORETOEXPLORE_0_VERSION='466-gog15616'
 
 ARCHIVE_BASE_EMPERORSCHALLENGE_7_NAME='renowned_explorers_international_society_the_emperors_challenge_dlc_522_26056.sh'
 ARCHIVE_BASE_EMPERORSCHALLENGE_7_MD5='e87af99e5a726b06ee5b94d7f94d9f5a'
-ARCHIVE_BASE_EMPERORSCHALLENGE_7_SIZE='22000'
+ARCHIVE_BASE_EMPERORSCHALLENGE_7_SIZE='21170'
 ARCHIVE_BASE_EMPERORSCHALLENGE_7_VERSION='522-gog26056'
 ARCHIVE_BASE_EMPERORSCHALLENGE_7_URL='https://www.gog.com/game/renowned_explorers_the_emperors_challenge'
 
@@ -115,7 +115,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 data/dlc_???.tim'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
