@@ -8,16 +8,16 @@ set -o errexit
 # Renowned Explorers
 ###
 
-script_version=20240412.1
+script_version=20240723.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='renowned-explorers'
 GAME_NAME='Renowned Explorers: International Society'
 
 ARCHIVE_BASE_9_NAME='renowned_explorers_international_society_522_26056.sh'
 ARCHIVE_BASE_9_MD5='fe38ae1c4dc2607923cc2a60019bff38'
-ARCHIVE_BASE_9_SIZE='1200000'
+ARCHIVE_BASE_9_SIZE='1107554'
 ARCHIVE_BASE_9_VERSION='522-gog26056'
 ARCHIVE_BASE_9_URL='https://www.gog.com/game/renowned_explorers'
 
@@ -74,17 +74,24 @@ x86/abbeycore'
 CONTENT_GAME_DATA_FILES='
 data
 soundbanks
+settings.ini
 *.bni'
 
+## The game seems to save files randomly in either "savedata" or "userdata".
+## We save both, even if it will probably end up using only one.
 USER_PERSISTENT_DIRECTORIES='
+savedata
 userdata'
+USER_PERSISTENT_FILES='
+settings.ini'
 
 APP_MAIN_EXE_BIN64='x86_64/abbeycore'
 APP_MAIN_EXE_BIN32='x86/abbeycore'
-## TODO: Check if a better icon could be extracted from the Windows build.
+## No original game icon is provided, even for the Windows build,
+## so we fall back on the GOG-specific icon.
 APP_MAIN_ICON='../support/icon.png'
 ## Work around inconsistent behaviour with some locales
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # Work around inconsistent behaviour with some locales
 export LANG=C
 '
@@ -94,14 +101,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc++abi.so.1
 libc++.so.1
@@ -119,6 +124,9 @@ libXrandr.so.2'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
