@@ -7,9 +7,9 @@ set -o errexit
 # Scrapland
 ###
 
-script_version=20240408.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='scrapland'
 GAME_NAME='Scrapland'
@@ -21,7 +21,7 @@ ARCHIVE_BASE_0_PART1_NAME='setup_scrapland_remastered_1.6.1_(52159)-1.bin'
 ARCHIVE_BASE_0_PART1_MD5='93c07bedabd25a0d63c7ae36cf5abd47'
 ARCHIVE_BASE_0_PART2_NAME='setup_scrapland_remastered_1.6.1_(52159)-2.bin'
 ARCHIVE_BASE_0_PART2_MD5='8543d603b9c8eb6d666aec35387c311c'
-ARCHIVE_BASE_0_SIZE='9000000'
+ARCHIVE_BASE_0_SIZE='8943631'
 ARCHIVE_BASE_0_VERSION='1.6.1-gog52159'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/scrapland_remastered'
 
@@ -56,7 +56,7 @@ WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE='bin/scrap.exe'
 ## Run the game binary from its parent directory.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # Run the game binary from its parent directory
 cd "$(dirname "$APP_EXE")"
 APP_EXE=$(basename "$APP_EXE")
@@ -68,6 +68,13 @@ PKG_L10N_EN
 PKG_L10N_FR
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N
+PKG_DATA'
+PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
+video/x-msvideo'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
@@ -81,11 +88,6 @@ PKG_L10N_FR_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_EN_DESCRIPTION='English localization'
 PKG_L10N_FR_DESCRIPTION='English localization'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
-video/x-msvideo'
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -139,7 +141,7 @@ launchers_generation 'PKG_BIN'
 # Build packages
 
 packages_generation
-case "${LANG%_*}" in
+case "$(messages_language)" in
 	('fr')
 		lang_string='version %s :'
 		lang_en='anglaise'
