@@ -7,9 +7,9 @@ set -o errexit
 # Shadow Tactics: Aiko's Choice
 ###
 
-script_version=20240409.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='shadow-tactics-aikos-choice'
 GAME_NAME='Shadow Tactics: Blades of the Shogun - Aikoʼs Choice'
@@ -19,7 +19,7 @@ ARCHIVE_BASE_0_MD5='5e0cfcc243f249fded7906fea04f6544'
 ARCHIVE_BASE_0_TYPE='innosetup'
 ARCHIVE_BASE_0_PART1_NAME='setup_shadow_tactics_blades_of_the_shogun_-_aikos_choice_3.2.25.f.r4769a_(51855)-1.bin'
 ARCHIVE_BASE_0_PART1_MD5='8bdc4420659b2382d742165fddb09705'
-ARCHIVE_BASE_0_SIZE='4600000'
+ARCHIVE_BASE_0_SIZE='4569291'
 ARCHIVE_BASE_0_VERSION='3.2.25.f.r4769a-gog51855'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/shadow_tactics_blades_of_the_shogun_aikos_choice'
 
@@ -35,12 +35,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
