@@ -7,16 +7,16 @@ set -o errexit
 # Shadow Tactics
 ###
 
-script_version=20240528.1
+script_version=20240711.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='shadow-tactics'
 GAME_NAME='Shadow Tactics: Blades of the Shogun'
 
 ARCHIVE_BASE_1_NAME='shadow_tactics_blades_of_the_shogun_en_2_2_10_f_21297.sh'
 ARCHIVE_BASE_1_MD5='e7772e7a5f4fee760e9311a9a899dbb3'
-ARCHIVE_BASE_1_SIZE='7800000'
+ARCHIVE_BASE_1_SIZE='7642154'
 ARCHIVE_BASE_1_VERSION='2.2.10.f-gog21297'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/shadow_tactics_blades_of_the_shogun'
 
@@ -39,14 +39,10 @@ PKG_BIN
 PKG_LIGHTING
 PKG_DATA'
 
-PKG_LIGHTING_ID="${GAME_ID}-lighting"
-PKG_LIGHTING_DESCRIPTION='lighting'
-
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_LIGHTING_ID $PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_LIGHTING
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -64,6 +60,12 @@ libX11.so.6
 libXcursor.so.1
 libXrandr.so.2'
 
+PKG_LIGHTING_ID="${GAME_ID}-lighting"
+PKG_LIGHTING_DESCRIPTION='lighting'
+
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
