@@ -11,9 +11,9 @@ set -o errexit
 # - Shadowrun: Hong Kong
 ###
 
-script_version=20240413.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_RETURNS='shadowrun-returns'
 GAME_NAME_RETURNS='Shadowrun Returns'
@@ -95,23 +95,9 @@ PKG_BIN
 PKG_DATA_STANDALONE
 PKG_DATA'
 
-PKG_DATA_ID_RETURNS="${GAME_ID_RETURNS}-data"
-PKG_DATA_ID_DRAGONFALL="${GAME_ID_DRAGONFALL}-data"
-PKG_DATA_ID_HONGKONG="${GAME_ID_HONGKONG}-data"
-PKG_DATA_DESCRIPTION='data'
-
-PKG_DATA_STANDALONE_ID_RETURNS="${PKG_DATA_ID_RETURNS}-standalone"
-PKG_DATA_STANDALONE_ID_DRAGONFALL="${PKG_DATA_ID_DRAGONFALL}-standalone"
-PKG_DATA_STANDALONE_ID_HONGKONG="${PKG_DATA_ID_HONGKONG}-standalone"
-PKG_DATA_STANDALONE_DESCRIPTION="$PKG_DATA_DESCRIPTION - standalone"
-PKG_DATA_DEPS_RETURNS="${PKG_DATA_DEPS:-} $PKG_DATA_STANDALONE_ID_RETURNS"
-PKG_DATA_DEPS_DRAGONFALL="${PKG_DATA_DEPS:-} $PKG_DATA_STANDALONE_ID_DRAGONFALL"
-PKG_DATA_DEPS_HONGKONG="${PKG_DATA_DEPS:-} $PKG_DATA_STANDALONE_ID_HONGKONG"
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS_RETURNS="$PKG_DATA_ID_RETURNS"
-PKG_BIN_DEPS_DRAGONFALL="$PKG_DATA_ID_DRAGONFALL"
-PKG_BIN_DEPS_HONGKONG="$PKG_DATA_ID_HONGKONG"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES_RETURNS='
 libc.so.6
 libdl.so.2
@@ -170,6 +156,18 @@ libstdc++.so.6
 libX11.so.6
 libXcursor.so.1'
 
+PKG_DATA_ID_RETURNS="${GAME_ID_RETURNS}-data"
+PKG_DATA_ID_DRAGONFALL="${GAME_ID_DRAGONFALL}-data"
+PKG_DATA_ID_HONGKONG="${GAME_ID_HONGKONG}-data"
+PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_STANDALONE'
+
+PKG_DATA_STANDALONE_ID_RETURNS="${PKG_DATA_ID_RETURNS}-standalone"
+PKG_DATA_STANDALONE_ID_DRAGONFALL="${PKG_DATA_ID_DRAGONFALL}-standalone"
+PKG_DATA_STANDALONE_ID_HONGKONG="${PKG_DATA_ID_HONGKONG}-standalone"
+PKG_DATA_STANDALONE_DESCRIPTION="$PKG_DATA_DESCRIPTION - standalone"
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
