@@ -8,16 +8,16 @@ set -o errexit
 # Shenzhen I/O
 ###
 
-script_version=20240413.2
+script_version=20240718.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='shenzhen-io'
 GAME_NAME='Shenzhen I/O'
 
 ARCHIVE_BASE_2_NAME='shenzhen_i_o_gog_4_26_03_2023_63470.sh'
 ARCHIVE_BASE_2_MD5='50afcbddbb5226c26d1bd4a2fc780f58'
-ARCHIVE_BASE_2_SIZE='460000'
+ARCHIVE_BASE_2_SIZE='449123'
 ARCHIVE_BASE_2_VERSION='2023.03.26-gog63470'
 ARCHIVE_BASE_2_URL='https://www.gog.com/game/shenzhen_io'
 
@@ -63,14 +63,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 ld-linux-x86-64.so.2
 libc.so.6
@@ -86,6 +84,9 @@ libvorbisfile.so.3'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -111,11 +112,6 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Apply common Mono tweaks
-
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-$(mono_launcher_tweaks)"
-
 # Extract game data
 
 archive_extraction_default
@@ -127,6 +123,10 @@ content_inclusion_default
 
 # Write launchers
 
+## Apply common Mono tweaks.
+APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
+$(mono_launcher_tweaks)"
+
 launchers_generation 'PKG_BIN64'
 launchers_generation 'PKG_BIN32'
 
