@@ -7,9 +7,9 @@ set -o errexit
 # Star Wars: Galactic Battlegrounds
 ###
 
-script_version=20240523.2
+script_version=20240720.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='star-wars-galactic-battlegrounds'
 GAME_NAME='Star Wars: Galactic Battlegrounds'
@@ -17,36 +17,36 @@ GAME_NAME='Star Wars: Galactic Battlegrounds'
 ARCHIVE_BASE_EN_0_NAME='setup_sw_galactic_battlegrounds_saga_2.0.0.4.exe'
 ARCHIVE_BASE_EN_0_MD5='6af25835c5f240914cb04f7b4f741813'
 ARCHIVE_BASE_EN_0_TYPE='innosetup'
+ARCHIVE_BASE_EN_0_SIZE='819518'
 ARCHIVE_BASE_EN_0_VERSION='1.1-gog2.0.0.4'
-ARCHIVE_BASE_EN_0_SIZE='830000'
 ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/star_wars_galactic_battlegrounds_saga'
 
 ARCHIVE_BASE_FR_0_NAME='setup_sw_galactic_battlegrounds_saga_french_2.0.0.4.exe'
 ARCHIVE_BASE_FR_0_MD5='b30458033e825ad252e2d5b3dc8a7845'
 ARCHIVE_BASE_FR_0_TYPE='innosetup'
+ARCHIVE_BASE_FR_0_SIZE='807572'
 ARCHIVE_BASE_FR_0_VERSION='1.1-gog2.0.0.4'
-ARCHIVE_BASE_FR_0_SIZE='820000'
 ARCHIVE_BASE_FR_0_URL='https://www.gog.com/game/star_wars_galactic_battlegrounds_saga'
 
 CONTENT_PATH_DEFAULT='app/game'
 CONTENT_GAME_BIN_FILES='
-*.exe
 libogg-0.dll
 libvorbis-0.dll
 libvorbisfile-3.dll
-win32.dll'
+win32.dll
+*.exe'
 CONTENT_GAME_L10N_FILES='
-language*.dll
-campaign/media/1c2s6_end.mm
-data/gamedata_x1.drs
-data/genie*.dat
-data/list*.crx
-data/sounds.*drs
 history
+taunt
 sound/campaign
 sound/scenario
+campaign/media/1c2s6_end.mm
+data/gamedata_x1.drs
 scenario/default0.scx
-taunt'
+data/list*.crx
+data/genie*.dat
+language*.dll
+data/sounds.*drs'
 CONTENT_GAME_DATA_FILES='
 ai
 campaign
@@ -86,20 +86,22 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_ID}-en"
-PKG_L10N_ID_FR="${PKG_L10N_ID}-fr"
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
-
 # Work around CD check
 
 registry_dump_nocd_file='registry-dumps/no-cd-check.reg'
