@@ -10,9 +10,9 @@ set -o errexit
 # - Star Wars: Knights of the Old Republic 2
 ###
 
-script_version=20240413.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_KOTOR1='star-wars-knights-of-the-old-republic-1'
 GAME_NAME_KOTOR1='Star Wars: Knights of the Old Republic'
@@ -178,46 +178,45 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 PKG_L10N_DESCRIPTION_DE='German localization'
 
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-
 ## Star Wars: Knights of the Old Republic 1
 
-PKG_L10N_ID_KOTOR1="${GAME_ID_KOTOR1}-l10n"
-PKG_L10N_ID_KOTOR1_EN="${PKG_L10N_ID_KOTOR1}-en"
-PKG_L10N_ID_KOTOR1_FR="${PKG_L10N_ID_KOTOR1}-fr"
-PKG_L10N_ID_KOTOR1_DE="${PKG_L10N_ID_KOTOR1}-de"
+PKG_L10N_BASE_ID_KOTOR1="${GAME_ID_KOTOR1}-l10n"
+PKG_L10N_ID_KOTOR1_EN="${PKG_L10N_BASE_ID_KOTOR1}-en"
+PKG_L10N_ID_KOTOR1_FR="${PKG_L10N_BASE_ID_KOTOR1}-fr"
+PKG_L10N_ID_KOTOR1_DE="${PKG_L10N_BASE_ID_KOTOR1}-de"
 PKG_L10N_PROVIDES_KOTOR1="
-$PKG_L10N_ID_KOTOR1"
+$PKG_L10N_BASE_ID_KOTOR1"
 PKG_L10N_DESCRIPTION_KOTOR1_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_KOTOR1_FR="$PKG_L10N_DESCRIPTION_FR"
 PKG_L10N_DESCRIPTION_KOTOR1_DE="$PKG_L10N_DESCRIPTION_DE"
 
 PKG_DATA_ID_KOTOR1="${GAME_ID_KOTOR1}-data"
 
-PKG_BIN_DEPS_KOTOR1="$PKG_L10N_ID_KOTOR1 $PKG_DATA_ID_KOTOR1"
-
 ## Star Wars: Knights of the Old Republic 2
 
-PKG_L10N_ID_KOTOR2="${GAME_ID_KOTOR2}-l10n"
-PKG_L10N_ID_KOTOR2_EN="${PKG_L10N_ID_KOTOR2}-en"
-PKG_L10N_ID_KOTOR2_FR="${PKG_L10N_ID_KOTOR2}-fr"
-PKG_L10N_ID_KOTOR2_DE="${PKG_L10N_ID_KOTOR2}-de"
+PKG_L10N_BASE_ID_KOTOR2="${GAME_ID_KOTOR2}-l10n"
+PKG_L10N_ID_KOTOR2_EN="${PKG_L10N_BASE_ID_KOTOR2}-en"
+PKG_L10N_ID_KOTOR2_FR="${PKG_L10N_BASE_ID_KOTOR2}-fr"
+PKG_L10N_ID_KOTOR2_DE="${PKG_L10N_BASE_ID_KOTOR2}-de"
 PKG_L10N_PROVIDES_KOTOR2="
-$PKG_L10N_ID_KOTOR2"
+$PKG_L10N_BASE_ID_KOTOR2"
 PKG_L10N_DESCRIPTION_KOTOR2_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_KOTOR2_FR="$PKG_L10N_DESCRIPTION_FR"
 PKG_L10N_DESCRIPTION_KOTOR2_DE="$PKG_L10N_DESCRIPTION_DE"
 
 PKG_DATA_ID_KOTOR2="${GAME_ID_KOTOR2}-data"
 
-PKG_BIN_DEPS_KOTOR2="$PKG_L10N_ID_KOTOR2 $PKG_DATA_ID_KOTOR2"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
