@@ -7,9 +7,9 @@ set -o errexit
 # Startopia
 ###
 
-script_version=20240523.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='startopia'
 GAME_NAME='Startopia'
@@ -74,14 +74,14 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
