@@ -7,9 +7,9 @@ set -o errexit
 # Stellaris
 ###
 
-script_version=20240620.1
+script_version=20240721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -144,19 +144,9 @@ PKG_DATA_MODELS_SHIPS
 PKG_DATA_MODELS
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
-PKG_DATA_MODELS_ID="${PKG_DATA_ID}-models"
-PKG_DATA_MODELS_DESCRIPTION="${PKG_DATA_DESCRIPTION} - models"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_MODELS_ID"
-
-PKG_DATA_MODELS_SHIPS_ID="${PKG_DATA_MODELS_ID}-ships"
-PKG_DATA_MODELS_SHIPS_DESCRIPTION="${PKG_DATA_MODELS_DESCRIPTION} - ships"
-PKG_DATA_MODELS_DEPS="${PKG_DATA_MODELS_DEPS:-} $PKG_DATA_MODELS_SHIPS_ID"
-
 PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -170,6 +160,19 @@ libuuid.so.1
 libX11.so.6
 libz.so.1'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_MODELS'
+
+PKG_DATA_MODELS_ID="${PKG_DATA_ID}-models"
+PKG_DATA_MODELS_DESCRIPTION="${PKG_DATA_DESCRIPTION} - models"
+PKG_DATA_MODELS_DEPENDENCIES_SIBLINGS='
+PKG_DATA_MODELS_SHIPS'
+
+PKG_DATA_MODELS_SHIPS_ID="${PKG_DATA_MODELS_ID}-ships"
+PKG_DATA_MODELS_SHIPS_DESCRIPTION="${PKG_DATA_MODELS_DESCRIPTION} - ships"
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -195,13 +198,6 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Force the use of system-provided SDL
-
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
-# Force the use of system-provided SDL.
-export SDL_DYNAMIC_API='$(path_libraries_system)/libSDL2-2.0.so.0'
-"
-
 # Extract game data
 
 archive_extraction_default
@@ -222,6 +218,16 @@ content_inclusion_default
 
 # Write launchers
 
+## Force the use of system-provided SDL.
+path_libraries_system=$(
+	set_current_package 'PKG_BIN'
+	path_libraries_system
+)
+APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
+# Force the use of system-provided SDL.
+export SDL_DYNAMIC_API='${path_libraries_system}/libSDL2-2.0.so.0'
+"
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
