@@ -7,18 +7,23 @@ set -o errexit
 # Sunless Skies
 ###
 
-script_version=20240413.1
+script_version=20240701.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='sunless-skies'
 GAME_NAME='Sunless Skies'
 
+ARCHIVE_BASE_2_NAME='sunless_skies_sovereign_edition_2_0_5_6e8c8ff_74416.sh'
+ARCHIVE_BASE_2_MD5='3405edfa656734537b13b253748fc556'
+ARCHIVE_BASE_2_SIZE='3276986'
+ARCHIVE_BASE_2_VERSION='2.0.5-gog74416'
+ARCHIVE_BASE_2_URL='https://www.gog.com/game/sunless_skies'
+
 ARCHIVE_BASE_1_NAME='sunless_skies_sovereign_edition_2_0_4_fcf0af7a_52215.sh'
 ARCHIVE_BASE_1_MD5='0d92a8c235d610e6ec560c25179c529a'
 ARCHIVE_BASE_1_SIZE='3300000'
 ARCHIVE_BASE_1_VERSION='2.0.4-gog52215'
-ARCHIVE_BASE_1_URL='https://www.gog.com/game/sunless_skies'
 
 ARCHIVE_BASE_0_NAME='sunless_skies_sovereign_edition_2_0_2_9bcd3d8c_48199.sh'
 ARCHIVE_BASE_0_MD5='f99de4c6a893be6f7fcb8170c94478f4'
