@@ -7,9 +7,9 @@ set -o errexit
 # Superflu Riteurnz
 ###
 
-script_version=20231222.2
+script_version=20240530.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='superflu-riteurnz'
 GAME_NAME='Superflu Riteurnz'
@@ -25,7 +25,7 @@ ARCHIVE_BASE_0_MD5='a147cebc30b9439321b5d6c8b8f04539'
 ARCHIVE_BASE_0_SIZE='353012'
 ARCHIVE_BASE_0_VERSION='1.5.5-itch.2023.11.22'
 
-## ./play.it 2.27 does not have good support for multiple archives sharing a same name.
+## ./play.it 2.29 does not have good support for multiple archives sharing a same name.
 ## cf. https://forge.dotslashplay.it/play.it/scripts/-/issues/355
 #ARCHIVE_BASE_MONOARCH_7_NAME='superfluous-returnz-1.5.5-d12-gnunux.tar.gz'
 #ARCHIVE_BASE_MONOARCH_7_MD5='6410e666d262dc32b4a143e5670d1805'
@@ -170,8 +170,7 @@ content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
