@@ -7,9 +7,9 @@ set -o errexit
 # The Settlers 2
 ###
 
-script_version=20240413.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='the-settlers-2'
 GAME_NAME='The Settlers Ⅱ'
@@ -21,7 +21,7 @@ GAME_NAME='The Settlers Ⅱ'
 ARCHIVE_BASE_DE_1_NAME='setup_the_settlers_2_gold_1.5.1_(german)_(30319).exe'
 ARCHIVE_BASE_DE_1_MD5='c360aaabd05e99b0f0752e52dd105107'
 ARCHIVE_BASE_DE_1_TYPE='innosetup'
-ARCHIVE_BASE_DE_1_SIZE='360000'
+ARCHIVE_BASE_DE_1_SIZE='358538'
 ARCHIVE_BASE_DE_1_VERSION='1.5.1-gog30319'
 ARCHIVE_BASE_DE_1_URL='https://www.gog.com/game/the_settlers_2_gold_edition'
 
@@ -36,7 +36,7 @@ ARCHIVE_BASE_DE_0_VERSION='1.5.1-gog2.1.0.17'
 ARCHIVE_BASE_EN_1_NAME='setup_the_settlers_2_gold_1.5.1_(30319).exe'
 ARCHIVE_BASE_EN_1_MD5='8381240ee580a298798b6afe863bac52'
 ARCHIVE_BASE_EN_1_TYPE='innosetup'
-ARCHIVE_BASE_EN_1_SIZE='370000'
+ARCHIVE_BASE_EN_1_SIZE='359765'
 ARCHIVE_BASE_EN_1_VERSION='1.5.1-gog30319'
 ARCHIVE_BASE_EN_1_URL='https://www.gog.com/game/the_settlers_2_gold_edition'
 
@@ -51,7 +51,7 @@ ARCHIVE_BASE_EN_0_VERSION='1.5.1-gog2.0.0.14'
 ARCHIVE_BASE_FR_1_NAME='setup_the_settlers_2_gold_1.5.1_(french)_(30319).exe'
 ARCHIVE_BASE_FR_1_MD5='55a9d15f1260de5e711ea649120ece50'
 ARCHIVE_BASE_FR_1_TYPE='innosetup'
-ARCHIVE_BASE_FR_1_SIZE='400000'
+ARCHIVE_BASE_FR_1_SIZE='395295'
 ARCHIVE_BASE_FR_1_VERSION='1.5.1-gog30319'
 ARCHIVE_BASE_FR_1_URL='https://www.gog.com/game/the_settlers_2_gold_edition'
 
@@ -196,7 +196,8 @@ $PKG_MAIN_ID"
 PKG_MAIN_DESCRIPTION_DE='German version'
 PKG_MAIN_DESCRIPTION_EN='English version'
 PKG_MAIN_DESCRIPTION_FR='French version'
-PKG_MAIN_DEPS="$PKG_COMMON_ID"
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_COMMON'
 
 # Load common functions
 
