@@ -9,9 +9,9 @@ set -o errexit
 # - Atlantis
 ###
 
-script_version=20240413.1
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='titan-quest'
 GAME_NAME='Titan Quest'
@@ -31,7 +31,7 @@ ARCHIVE_BASE_RAGNAROK_0_MD5='cb8f5a3f5567d9f84ad3add23347ad07'
 ARCHIVE_BASE_RAGNAROK_0_TYPE='innosetup'
 ARCHIVE_BASE_RAGNAROK_0_PART1_NAME='setup_titan_quest_ragnarok_2.10.6_(59562)-1.bin'
 ARCHIVE_BASE_RAGNAROK_0_PART1_MD5='e4a5d3bb1264c1a3881e2263cd3d6af3'
-ARCHIVE_BASE_RAGNAROK_0_SIZE='2600000'
+ARCHIVE_BASE_RAGNAROK_0_SIZE='2553284'
 ARCHIVE_BASE_RAGNAROK_0_VERSION='2.10.6-gog59562'
 ARCHIVE_BASE_RAGNAROK_0_URL='https://www.gog.com/game/titan_quest_ragnarok'
 
@@ -42,7 +42,7 @@ ARCHIVE_BASE_ATLANTIS_0_MD5='6924de3dc1dd15eec6f1e4e6d465f33c'
 ARCHIVE_BASE_ATLANTIS_0_TYPE='innosetup'
 ARCHIVE_BASE_ATLANTIS_0_PART1_NAME='setup_titan_quest_atlantis_2.10.6_(59562)-1.bin'
 ARCHIVE_BASE_ATLANTIS_0_PART1_MD5='2ad964c3cf35c13a0e05b7680b62d718'
-ARCHIVE_BASE_ATLANTIS_0_SIZE='2300000'
+ARCHIVE_BASE_ATLANTIS_0_SIZE='2265041'
 ARCHIVE_BASE_ATLANTIS_0_VERSION='2.10.6-gog59562'
 ARCHIVE_BASE_ATLANTIS_0_URL='https://www.gog.com/game/titan_quest_atlantis'
 
@@ -65,9 +65,12 @@ resources/xpack3/menu.arc
 resources/xpack3/quests.arc
 resources/xpack3/system.arc'
 
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 PKG_MAIN_PROVIDES_RAGNAROK="
 ${GAME_ID}-data-xpack2"
-PKG_MAIN_DEPS="$GAME_ID"
 
 # Load common functions
 
