@@ -7,9 +7,9 @@ set -o errexit
 # Titan Quest
 ###
 
-script_version=20240606.3
+script_version=20240717.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='titan-quest'
 GAME_NAME='Titan Quest'
@@ -25,7 +25,7 @@ ARCHIVE_BASE_0_PART3_NAME='setup_titan_quest_-_anniversary_edition_2.10.6_(59562
 ARCHIVE_BASE_0_PART3_MD5='bb6bcb03b2ef688ef57d46d12d4b1233'
 ARCHIVE_BASE_0_PART4_NAME='setup_titan_quest_-_anniversary_edition_2.10.6_(59562)-4.bin'
 ARCHIVE_BASE_0_PART4_MD5='2a61ebe44e9424cdbad29f14e072c743'
-ARCHIVE_BASE_0_SIZE='14000000'
+ARCHIVE_BASE_0_SIZE='13753628'
 ARCHIVE_BASE_0_VERSION='2.10.21415-gog59562'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/titan_quest_anniversary_edition'
 
@@ -108,19 +108,21 @@ PKG_DATA_XPACK2
 PKG_DATA_RESOURCES
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_XPACK2
+PKG_DATA_RESOURCES'
 
 PKG_DATA_XPACK2_ID="${PKG_DATA_ID}-xpack2"
 PKG_DATA_XPACK2_DESCRIPTION='resources shared between the base game and the Raganarök expansion'
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_XPACK2_ID"
 
 PKG_DATA_RESOURCES_ID="${PKG_DATA_ID}-resources"
 PKG_DATA_RESOURCES_DESCRIPTION="$PKG_DATA_DESCRIPTION - resources"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_RESOURCES_ID"
-
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
 
 # Load common functions
 
