@@ -7,9 +7,9 @@ set -o errexit
 # Torchlight 1
 ###
 
-script_version=20240416.1
+script_version=20240718.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='torchlight-1'
 GAME_NAME='Torchlight'
@@ -17,7 +17,7 @@ GAME_NAME='Torchlight'
 ARCHIVE_BASE_1_NAME='setup_torchlight_1.15(a)_(23675).exe'
 ARCHIVE_BASE_1_MD5='a29e51f55aae740f4046d227d33fa64b'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_SIZE='460000'
+ARCHIVE_BASE_1_SIZE='453318'
 ARCHIVE_BASE_1_VERSION='1.15-gog23675'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/torchlight'
 
@@ -30,9 +30,27 @@ ARCHIVE_BASE_0_VERSION='1.15-gog2.0.0.12'
 CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_0='app'
 CONTENT_GAME_BIN_FILES='
-torchlight.exe
-*.cfg
-*.dll'
+plugins.cfg
+resources.cfg
+ceguibase.dll
+ceguiexpatparser.dll
+ceguifalagardwrbase.dll
+cg.dll
+d3dx9_39.dll
+fmodex.dll
+msvcp90.dll
+msvcr90.dll
+ogreguirenderer.dll
+ogremain.dll
+ois.dll
+particleuniverse.dll
+plugin_cgprogrammanager.dll
+plugin_octreescenemanager.dll
+plugin_particlefx.dll
+referenceapplayer.dll
+rendersystem_direct3d9.dll
+rendersystem_gl.dll
+torchlight.exe'
 CONTENT_GAME_DATA_FILES='
 buildver.txt
 runicgames.ico
@@ -55,12 +73,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -89,14 +108,6 @@ fi
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Drop unwanted files.
-	rm --force --recursive \
-		'commonappdata' \
-		'tmp'
-)
 
 # Include game data
 
