@@ -7,22 +7,22 @@ set -o errexit
 # Torchlight 2
 ###
 
-script_version=20240416.1
+script_version=20240718.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='torchlight-2'
 GAME_NAME='Torchlight Ⅱ'
 
 ARCHIVE_BASE_GOG_0_NAME='gog_torchlight_2_2.0.0.2.sh'
 ARCHIVE_BASE_GOG_0_MD5='e107f6d4c6d4cecea37ade420a8d4892'
-ARCHIVE_BASE_GOG_0_SIZE='1700000'
+ARCHIVE_BASE_GOG_0_SIZE='1673501'
 ARCHIVE_BASE_GOG_0_VERSION='1.25.9.7-gog2.0.0.2'
 ARCHIVE_BASE_GOG_0_URL='https://www.gog.com/game/torchlight_ii'
 
 ARCHIVE_BASE_HUMBLE_0_NAME='Torchlight2-linux-2015-04-01.sh'
 ARCHIVE_BASE_HUMBLE_0_MD5='730a5d08c8f1cd4a65afbc0ca631d85c'
-ARCHIVE_BASE_HUMBLE_0_SIZE='1700000'
+ARCHIVE_BASE_HUMBLE_0_SIZE='1672909'
 ARCHIVE_BASE_HUMBLE_0_VERSION='1.25.2.4-humble150402'
 ARCHIVE_BASE_HUMBLE_0_URL='https://www.humblebundle.com/store/torchlight-ii'
 
@@ -53,15 +53,15 @@ Torchlight2.bin.x86
 ModLauncher.bin.x86'
 CONTENT_GAME_DATA_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/noarch"
 CONTENT_GAME_DATA_FILES='
-*.bmp
-*.cfg
-*.png
 icons
 movies
 music
 PAKS
 porting
-programs'
+programs
+*.bmp
+*.cfg
+*.png'
 CONTENT_DOC_DATA_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/noarch"
 CONTENT_DOC_DATA_FILES='
 licenses'
@@ -76,14 +76,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -108,6 +106,9 @@ libz.so.1'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
