@@ -8,16 +8,16 @@ set -o errexit
 # Transistor
 ###
 
-script_version=20240416.1
+script_version=20240718.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='transistor'
 GAME_NAME='Transistor'
 
 ARCHIVE_BASE_2_NAME='transistor_1_50440_8123_23365.sh'
 ARCHIVE_BASE_2_MD5='dc89c175267dc1a1f3434a9d4f903cce'
-ARCHIVE_BASE_2_SIZE='3600000'
+ARCHIVE_BASE_2_SIZE='3580037'
 ARCHIVE_BASE_2_VERSION='1.50440.8123-gog23365'
 ARCHIVE_BASE_2_URL='https://www.gog.com/game/transistor'
 
@@ -79,6 +79,8 @@ PKG_MAIN
 PKG_LIBS64
 PKG_LIBS32'
 
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_LIBS'
 PKG_MAIN_DEPENDENCIES_LIBRARIES='
 libGL.so.1
 libSDL2-2.0.so.0'
@@ -102,8 +104,8 @@ System.Xml.Linq.dll'
 
 PKG_LIBS_ID="${GAME_ID}-libs"
 PKG_LIBS64_ID="$PKG_LIBS_ID"
-PKG_LIBS64_ARCH='64'
 PKG_LIBS32_ID="$PKG_LIBS_ID"
+PKG_LIBS64_ARCH='64'
 PKG_LIBS32_ARCH='32'
 PKG_LIBS_DEPENDENCIES_LIBRARIES='
 libc.so.6
