@@ -9,9 +9,9 @@ set -o errexit
 # - Tropico 2
 ###
 
-script_version=20240409.1
+script_version=20240606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID_TROPICO1='tropico-1'
 GAME_NAME_TROPICO1='Tropico'
@@ -108,41 +108,40 @@ PKG_BIN
 PKG_L10N
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
+
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
 
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-
 ## Tropico 1
 
-PKG_L10N_ID_TROPICO1="${GAME_ID_TROPICO1}-l10n"
-PKG_L10N_ID_TROPICO1_EN="${PKG_L10N_ID_TROPICO1}-en"
-PKG_L10N_ID_TROPICO1_FR="${PKG_L10N_ID_TROPICO1}-fr"
+PKG_L10N_BASE_ID_TROPICO1="${GAME_ID_TROPICO1}-l10n"
+PKG_L10N_ID_TROPICO1_EN="${PKG_L10N_BASE_ID_TROPICO1}-en"
+PKG_L10N_ID_TROPICO1_FR="${PKG_L10N_BASE_ID_TROPICO1}-fr"
 PKG_L10N_PROVIDES_TROPICO1="
-$PKG_L10N_ID_TROPICO1"
+$PKG_L10N_BASE_ID_TROPICO1"
 PKG_L10N_DESCRIPTION_TROPICO1_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_TROPICO1_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_TROPICO1="${GAME_ID_TROPICO1}-data"
 
-PKG_BIN_DEPS_TROPICO1="$PKG_L10N_ID_TROPICO1 $PKG_DATA_ID_TROPICO1"
-
 ## Tropico 2
 
-PKG_L10N_ID_TROPICO2="${GAME_ID_TROPICO2}-l10n"
-PKG_L10N_ID_TROPICO2_EN="${PKG_L10N_ID_TROPICO2}-en"
-PKG_L10N_ID_TROPICO2_FR="${PKG_L10N_ID_TROPICO2}-fr"
+PKG_L10N_BASE_ID_TROPICO2="${GAME_ID_TROPICO2}-l10n"
+PKG_L10N_ID_TROPICO2_EN="${PKG_L10N_BASE_ID_TROPICO2}-en"
+PKG_L10N_ID_TROPICO2_FR="${PKG_L10N_BASE_ID_TROPICO2}-fr"
 PKG_L10N_PROVIDES_TROPICO2="
-$PKG_L10N_ID_TROPICO2"
+$PKG_L10N_BASE_ID_TROPICO2"
 PKG_L10N_DESCRIPTION_TROPICO2_EN="$PKG_L10N_DESCRIPTION_EN"
 PKG_L10N_DESCRIPTION_TROPICO2_FR="$PKG_L10N_DESCRIPTION_FR"
 
 PKG_DATA_ID_TROPICO2="${GAME_ID_TROPICO2}-data"
 
-PKG_BIN_DEPS_TROPICO2="$PKG_L10N_ID_TROPICO2 $PKG_DATA_ID_TROPICO2"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
