@@ -11,9 +11,9 @@ set -o errexit
 # - Bastard's Wound
 ###
 
-script_version=20240416.1
+script_version=20240718.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='tyranny'
 GAME_NAME='Tyranny'
@@ -36,7 +36,7 @@ EXPANSION_NAME_WOUND='Bastardʼs Wound'
 
 ARCHIVE_BASE_COATOFARMS_0_NAME='tyranny_coat_of_arms_dlc_en_1_0_14773.sh'
 ARCHIVE_BASE_COATOFARMS_0_MD5='ba1403ce1f2535a00ae137c19204459f'
-ARCHIVE_BASE_COATOFARMS_0_SIZE='1700'
+ARCHIVE_BASE_COATOFARMS_0_SIZE='1342'
 ARCHIVE_BASE_COATOFARMS_0_VERSION='1.0-gog14773'
 ARCHIVE_BASE_COATOFARMS_0_URL='https://www.gog.com/game/tyranny_overlord_edition_upgrade'
 
@@ -44,7 +44,7 @@ ARCHIVE_BASE_COATOFARMS_0_URL='https://www.gog.com/game/tyranny_overlord_edition
 
 ARCHIVE_BASE_PORTRAIT_0_NAME='tyranny_portrait_pack_dlc_en_1_0_14773.sh'
 ARCHIVE_BASE_PORTRAIT_0_MD5='165e1cf02119a0b2ddb4d8bfa8b6819d'
-ARCHIVE_BASE_PORTRAIT_0_SIZE='4600'
+ARCHIVE_BASE_PORTRAIT_0_SIZE='4150'
 ARCHIVE_BASE_PORTRAIT_0_VERSION='1.0-gog14773'
 ARCHIVE_BASE_PORTRAIT_0_URL='https://www.gog.com/game/tyranny_portrait_pack'
 
@@ -52,7 +52,7 @@ ARCHIVE_BASE_PORTRAIT_0_URL='https://www.gog.com/game/tyranny_portrait_pack'
 
 ARCHIVE_BASE_TALES_0_NAME='tyranny_tales_from_the_tiers_dlc_en_1_2_1_0158_15398.sh'
 ARCHIVE_BASE_TALES_0_MD5='08676e535375b162e2fa32b1bc4488a3'
-ARCHIVE_BASE_TALES_0_SIZE='5700'
+ARCHIVE_BASE_TALES_0_SIZE='4386'
 ARCHIVE_BASE_TALES_0_VERSION='1.2.1.0158-gog15398'
 ARCHIVE_BASE_TALES_0_URL='https://www.gog.com/game/tyranny_tales_from_the_tiers'
 
@@ -60,7 +60,7 @@ ARCHIVE_BASE_TALES_0_URL='https://www.gog.com/game/tyranny_tales_from_the_tiers'
 
 ARCHIVE_BASE_WOUND_0_NAME='tyranny_bastard_s_wound_dlc_en_1_2_1_0158_15398.sh'
 ARCHIVE_BASE_WOUND_0_MD5='dbd2b51a410db2357b2e144f44139c19'
-ARCHIVE_BASE_WOUND_0_SIZE='1200000'
+ARCHIVE_BASE_WOUND_0_SIZE='1159755'
 ARCHIVE_BASE_WOUND_0_VERSION='1.2.1.0158-gog15398'
 ARCHIVE_BASE_WOUND_0_URL='https://www.gog.com/game/tyranny_bastards_wound'
 
@@ -69,7 +69,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 Tyranny_Data'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
