@@ -7,16 +7,16 @@ set -o errexit
 # Tyranny
 ###
 
-script_version=20240416.1
+script_version=20240718.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='tyranny'
 GAME_NAME='Tyranny'
 
 ARCHIVE_BASE_0_NAME='tyranny_v1_2_1_160_v2_25169.sh'
 ARCHIVE_BASE_0_MD5='72bdb7c9f6966ac6f1ccfbbad9fb29e6'
-ARCHIVE_BASE_0_SIZE='16000000'
+ARCHIVE_BASE_0_SIZE='15136872'
 ARCHIVE_BASE_0_VERSION='1.2.1.0160-gog25169'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/tyranny_commander_edition'
 
@@ -40,17 +40,13 @@ PKG_BIN32
 PKG_AREAS
 PKG_DATA'
 
-PKG_AREAS_ID="${GAME_ID}-areas"
-PKG_AREAS_DESCRIPTION='areas'
-
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_AREAS_ID $PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_AREAS
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -73,6 +69,12 @@ libz.so.1'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_AREAS_ID="${GAME_ID}-areas"
+PKG_AREAS_DESCRIPTION='areas'
+
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
