@@ -9,9 +9,9 @@ set -o errexit
 # Unreal Tournament
 ###
 
-script_version=20231212.1
+script_version=20240530.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='unreal-tournament'
 GAME_NAME='Unreal Tournament'
@@ -23,9 +23,9 @@ GAME_NAME='Unreal Tournament'
 
 ARCHIVE_BASE_0_NAME='setup_ut_goty_2.0.0.5.exe'
 ARCHIVE_BASE_0_MD5='0d25ec835648710a098aff7106187f38'
-ARCHIVE_BASE_0_EXTRACTOR='innoextract'
 ## Do not convert file paths to lowercase.
-ARCHIVE_BASE_0_EXTRACTOR_OPTIONS='--progress=1 --silent'
+ARCHIVE_BASE_0_EXTRACTOR='innoextract'
+ARCHIVE_BASE_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_0_SIZE='640000'
 ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.5'
 
@@ -89,7 +89,7 @@ LICENSE.md'
 
 APP_MAIN_EXE='System64/ut-bin-amd64'
 APP_MAIN_ICON='System/Unreal.ico'
-## Run the game binary from its parent directory
+## Run the game binary from its parent directory.
 APP_MAIN_PRERUN='# Run the game binary from its parent directory
 cd "$(dirname "$APP_EXE")"
 APP_EXE=$(basename "$APP_EXE")
@@ -188,14 +188,12 @@ archive_extraction 'ARCHIVE_ENGINE'
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
