@@ -8,9 +8,9 @@ set -o errexit
 # Vampire: The Masquerade - Bloodlines
 ###
 
-script_version=20240410.2
+script_version=20240712.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='vampire-the-masquerade-bloodlines'
 GAME_NAME='Vampire: The Masquerade - Bloodlines'
@@ -19,7 +19,7 @@ GAME_NAME='Vampire: The Masquerade - Bloodlines'
 ARCHIVE_BASE_DOTEMU_0_NAME='vampire_the_masquerade_bloodlines_v1.2.exe'
 ARCHIVE_BASE_DOTEMU_0_MD5='8981da5fa644475583b2888a67fdd741'
 ARCHIVE_BASE_DOTEMU_0_EXTRACTOR='unar'
-ARCHIVE_BASE_DOTEMU_0_SIZE='3000000'
+ARCHIVE_BASE_DOTEMU_0_SIZE='5013863'
 ARCHIVE_BASE_DOTEMU_0_VERSION='1.2-dotemu1'
 
 ARCHIVE_BASE_GOG_EN_5_NAME='setup_vampire_the_masquerade_-_bloodlines_1.2_(up_11.511.410.2)_(68368).exe'
@@ -168,7 +168,7 @@ WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE='vampire.exe'
 ## Work around the deletion of zlib1.dll.
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+APP_MAIN_PRERUN='
 # Work around the deletion of zlib1.dll
 system_library="${WINEPREFIX}/drive_c/windows/system32/zlib1.dll"
 if [ ! -e "$system_library" ]; then
@@ -193,7 +193,7 @@ if [ -z "${WAYLAND_DISPLAY:-}" ] && [ -n "${DISPLAY:-}" ] && command -v setxkbma
 	fi
 fi
 '
-APP_MAIN_POSTRUN="${APP_MAIN_POSTRUN:-}"'
+APP_MAIN_POSTRUN='
 # Restore the keyboard variant, if it has previously been switched to us-azerty.
 ## This works on X.org only, not on Wayland.
 if [ -z "${WAYLAND_DISPLAY:-}" ] && [ -n "${DISPLAY:-}" ] && command -v setxkbmap >/dev/null 2>&1; then
@@ -217,21 +217,23 @@ PKG_BIN
 PKG_L10N_FR
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_L10N_BASE
+PKG_DATA'
 
-PKG_L10N_ID="${GAME_ID}-l10n"
-PKG_L10N_EN_ID="${PKG_L10N_ID}-en"
-PKG_L10N_FR_ID="${PKG_L10N_ID}-fr"
+PKG_L10N_BASE_ID="${GAME_ID}-l10n"
+PKG_L10N_EN_ID="${PKG_L10N_BASE_ID}-en"
+PKG_L10N_FR_ID="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
-$PKG_L10N_ID"
+$PKG_L10N_BASE_ID"
 PKG_L10N_EN_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_FR_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_EN_ENSCRIPTION='English localization'
 PKG_L10N_FR_FRSCRIPTION='French localization'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
 
 # Load common functions
 
@@ -329,7 +331,7 @@ launchers_generation 'PKG_BIN'
 packages_generation
 case "$(current_archive)" in
 	('ARCHIVE_BASE_DOTEMU_'*)
-		case "${LANG%_*}" in
+		case "$(messages_language)" in
 			('fr')
 				lang_string='version %s :'
 				lang_en='anglaise'
