@@ -9,9 +9,9 @@ set -o errexit
 # - Fractured Worlds
 ###
 
-script_version=20240416.1
+script_version=20240719.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='victor-vran'
 GAME_NAME='Victor Vran'
@@ -28,7 +28,7 @@ EXPANSION_NAME_FRACTURED='Fractured Worlds'
 
 ARCHIVE_BASE_MOTORHEAD_0_NAME='victor_vran_mot_rhead_through_the_ages_2_07_20181005_24296.sh'
 ARCHIVE_BASE_MOTORHEAD_0_MD5='e84685034d2d90782a3ab7c83901bc11'
-ARCHIVE_BASE_MOTORHEAD_0_SIZE='870000'
+ARCHIVE_BASE_MOTORHEAD_0_SIZE='868392'
 ARCHIVE_BASE_MOTORHEAD_0_VERSION='2.07.20181005-gog24296'
 ARCHIVE_BASE_MOTORHEAD_0_URL='https://www.gog.com/game/victor_vran_motorhead_through_the_ages'
 
@@ -36,7 +36,7 @@ ARCHIVE_BASE_MOTORHEAD_0_URL='https://www.gog.com/game/victor_vran_motorhead_thr
 
 ARCHIVE_BASE_FRACTURED_0_NAME='victor_vran_fractured_worlds_2_07_20181005_24296.sh'
 ARCHIVE_BASE_FRACTURED_0_MD5='94a8bd9f2ca09e3c4e2547a0d5a7bc8c'
-ARCHIVE_BASE_FRACTURED_0_SIZE='220000'
+ARCHIVE_BASE_FRACTURED_0_SIZE='213785'
 ARCHIVE_BASE_FRACTURED_0_VERSION='2.07.20181005-gog24296'
 ARCHIVE_BASE_FRACTURED_0_URL='https://www.gog.com/game/victor_vran_fractured_worlds'
 
@@ -45,7 +45,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 DLC'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
