@@ -8,16 +8,16 @@ set -o errexit
 # Victor Vran
 ###
 
-script_version=20240502.1
+script_version=20240719.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.29'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='victor-vran'
 GAME_NAME='Victor Vran'
 
 ARCHIVE_BASE_0_NAME='victor_vran_2_07_20181005_24296.sh'
 ARCHIVE_BASE_0_MD5='506f55f5521131e7ab69b656a3e55582'
-ARCHIVE_BASE_0_SIZE='5000000'
+ARCHIVE_BASE_0_SIZE='4721209'
 ARCHIVE_BASE_0_VERSION='2.07.20181005-gog24296'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/victor_vran'
 
@@ -32,8 +32,9 @@ Packs'
 
 APP_MAIN_EXE='VictorVranGOG'
 APP_MAIN_ICON='../support/icon.png'
-## Work around a failure to launch due to not parsing the correct SSL configuration
-APP_MAIN_PRERUN='# Work around a failure to launch due to not parsing the correct SSL configuration
+## Work around a failure to launch due to not parsing the correct SSL configuration.
+APP_MAIN_PRERUN='
+# Work around a failure to launch due to not parsing the correct SSL configuration
 export OPENSSL_CONF=/etc/ssl
 '
 
@@ -41,11 +42,9 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libcurl-gnutls.so.4
@@ -63,11 +62,13 @@ libXrandr.so.2
 libXrender.so.1
 libXt.so.6'
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 PRELOAD_HACKS_LIST='
 HACK_NOATIME'
 
-# LD_PRELOAD shim working around the engine expectation that files are owned by the current user
-
+## LD_PRELOAD shim working around the engine expectation that files are owned by the current user.
 HACK_NOATIME_NAME='vv_noatime'
 HACK_NOATIME_DESCRIPTION='LD_PRELOAD shim working around the engine expectation that files are owned by the current user'
 HACK_NOATIME_PACKAGE='PKG_BIN'
