@@ -13,9 +13,9 @@ set -o errexit
 # - Unavowed
 ###
 
-script_version=20240127.2
+script_version=20240628.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID_SHIVAH='the-shivah'
 GAME_NAME_SHIVAH='The Shivah'
@@ -50,6 +50,19 @@ ARCHIVE_BASE_SHIVAH_0_MD5='da6d89db273313fe00a680c52554aea3'
 ARCHIVE_BASE_SHIVAH_0_SIZE='170000'
 ARCHIVE_BASE_SHIVAH_0_VERSION='2.0-gog53607'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_SHIVAH='the-shivah_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_SHIVAH='76cb6554e1c09596842391a71e696ded'
+ARCHIVE_OPTIONAL_ICONS_URL_SHIVAH='https://downloads.dotslashplay.it/games/the-shivah/'
+CONTENT_ICONS_PATH_SHIVAH='.'
+CONTENT_ICONS_FILES_SHIVAH='
+16x16
+24x24
+32x32
+48x48
+256x256'
+
 ## Gemini Rue
 
 ARCHIVE_BASE_GEMINIRUE_3_NAME='gemini_rue_3_0_1_66504.sh'
@@ -73,6 +86,15 @@ ARCHIVE_BASE_GEMINIRUE_0_MD5='9626ba73b964458b26e25ed9e1ec737d'
 ARCHIVE_BASE_GEMINIRUE_0_SIZE='340000'
 ARCHIVE_BASE_GEMINIRUE_0_VERSION='2.0a-gog53346'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_GEMINIRUE='gemini-rue_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_GEMINIRUE='329019f63b1acdfe7c4d5219a562efab'
+ARCHIVE_OPTIONAL_ICONS_URL_GEMINIRUE='https://downloads.dotslashplay.it/games/gemini-rue/'
+CONTENT_ICONS_PATH_GEMINIRUE='.'
+CONTENT_ICONS_FILES_GEMINIRUE='
+256x256'
+
 ## Resonance
 
 ARCHIVE_BASE_RESONANCE_1_NAME='resonance_3_0_66305.sh'
@@ -86,13 +108,31 @@ ARCHIVE_BASE_RESONANCE_0_MD5='5c86f3f82974b65ad3d2852c6a9338ed'
 ARCHIVE_BASE_RESONANCE_0_SIZE='1200000'
 ARCHIVE_BASE_RESONANCE_0_VERSION='2.2-gog53439'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_RESONANCE='resonance_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_RESONANCE='0a24712adffd9f5f2998bf355fc161b7'
+ARCHIVE_OPTIONAL_ICONS_URL_RESONANCE='https://downloads.dotslashplay.it/games/resonance/'
+CONTENT_ICONS_PATH_RESONANCE='.'
+CONTENT_ICONS_FILES_RESONANCE='
+16x16
+24x24
+32x32
+48x48
+256x256'
+
 ## Technobabylon
 
+ARCHIVE_BASE_TECHNOBABYLON_4_NAME='technobabylon_3_0_5_72309.sh'
+ARCHIVE_BASE_TECHNOBABYLON_4_MD5='42a3d460d92a5a778d009eebd7b2b867'
+ARCHIVE_BASE_TECHNOBABYLON_4_SIZE='1374766'
+ARCHIVE_BASE_TECHNOBABYLON_4_VERSION='3.0.5-gog72309'
+ARCHIVE_BASE_TECHNOBABYLON_4_URL='https://www.gog.com/game/technobabylon'
+
 ARCHIVE_BASE_TECHNOBABYLON_3_NAME='technobabylon_3_0_1_66582.sh'
 ARCHIVE_BASE_TECHNOBABYLON_3_MD5='6ddf6ed6e8df026f548025a90585a382'
 ARCHIVE_BASE_TECHNOBABYLON_3_SIZE='1400000'
 ARCHIVE_BASE_TECHNOBABYLON_3_VERSION='3.0.1-gog66582'
-ARCHIVE_BASE_TECHNOBABYLON_3_URL='https://www.gog.com/game/technobabylon'
 
 ARCHIVE_BASE_TECHNOBABYLON_2_NAME='technobabylon_3_0_66305.sh'
 ARCHIVE_BASE_TECHNOBABYLON_2_MD5='5d522aa6349e26596e7a6e0ad3c5ff19'
@@ -109,13 +149,27 @@ ARCHIVE_BASE_TECHNOBABYLON_0_MD5='6bb58eccb57e2195d49266bd8798a9a1'
 ARCHIVE_BASE_TECHNOBABYLON_0_SIZE='1400000'
 ARCHIVE_BASE_TECHNOBABYLON_0_VERSION='2.1-gog53388'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_TECHNOBABYLON='technobabylon_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_TECHNOBABYLON='84a7104801c25d5e931fbdd4cc3d1916'
+ARCHIVE_OPTIONAL_ICONS_URL_TECHNOBABYLON='https://downloads.dotslashplay.it/games/technobabylon/'
+CONTENT_ICONS_PATH_TECHNOBABYLON='.'
+CONTENT_ICONS_FILES_TECHNOBABYLON='
+64x64'
+
 ## Shardlight
 
+ARCHIVE_BASE_SHARDLIGHT_4_NAME='shardlight_3_2_73879.sh'
+ARCHIVE_BASE_SHARDLIGHT_4_MD5='0207dcb6ee38949386c7ebe49ef18160'
+ARCHIVE_BASE_SHARDLIGHT_4_SIZE='952797'
+ARCHIVE_BASE_SHARDLIGHT_4_VERSION='3.2-gog73879'
+ARCHIVE_BASE_SHARDLIGHT_4_URL='https://www.gog.com/game/shardlight'
+
 ARCHIVE_BASE_SHARDLIGHT_3_NAME='shardlight_3_1_70695.sh'
 ARCHIVE_BASE_SHARDLIGHT_3_MD5='824cd0bf02463cfce8acd9c491399197'
 ARCHIVE_BASE_SHARDLIGHT_3_SIZE='952796'
 ARCHIVE_BASE_SHARDLIGHT_3_VERSION='3.1-gog70695'
-ARCHIVE_BASE_SHARDLIGHT_3_URL='https://www.gog.com/game/shardlight'
 
 ARCHIVE_BASE_SHARDLIGHT_2_NAME='shardlight_3_0_66305.sh'
 ARCHIVE_BASE_SHARDLIGHT_2_MD5='2c3d7b7e0a541ee3a635189449608713'
@@ -132,6 +186,16 @@ ARCHIVE_BASE_SHARDLIGHT_0_MD5='b48f7b1aac9b32ee7f5b236b6cc82e81'
 ARCHIVE_BASE_SHARDLIGHT_0_SIZE='1200000'
 ARCHIVE_BASE_SHARDLIGHT_0_VERSION='2.2-gog53577'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_SHARDLIGHT='shardlight_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_SHARDLIGHT='59bce49abce9678d963cecd72be8b512'
+ARCHIVE_OPTIONAL_ICONS_URL_SHARDLIGHT='https://downloads.dotslashplay.it/games/shardlight/'
+CONTENT_ICONS_PATH_SHARDLIGHT='.'
+CONTENT_ICONS_FILES_SHARDLIGHT='
+16x16
+32x32'
+
 ## Unavowed
 
 ARCHIVE_BASE_UNAVOWED_7_NAME='unavowed_2_0_2_70667.sh'
@@ -175,6 +239,19 @@ ARCHIVE_BASE_UNAVOWED_0_MD5='f0060c808571a4324714c69f653a4caa'
 ARCHIVE_BASE_UNAVOWED_0_SIZE='2500000'
 ARCHIVE_BASE_UNAVOWED_0_VERSION='1.3.1-gog54237'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_UNAVOWED='unavowed_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_UNAVOWED='359eae49cc167a34a1cc5525cf6ab340'
+ARCHIVE_OPTIONAL_ICONS_URL_UNAVOWED='https://downloads.dotslashplay.it/games/unavowed/'
+CONTENT_ICONS_PATH_UNAVOWED='.'
+CONTENT_ICONS_FILES_UNAVOWED='
+16x16
+24x24
+32x32
+48x48
+256x256'
+
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
@@ -190,7 +267,26 @@ Sounds
 CONTENT_DOC_MAIN_FILES='
 licenses'
 
-APP_MAIN_SCUMMID='ags'
+## TODO: Check if "ags:shivahkosher" should be used instead.
+APP_MAIN_SCUMMID_SHIVAH='ags:shivah'
+APP_MAIN_SCUMMID_GEMINIRUE='ags:geminirue'
+APP_MAIN_SCUMMID_RESONANCE='ags:resonance'
+APP_MAIN_SCUMMID_TECHNOBABYLON='ags:technobabylon'
+APP_MAIN_SCUMMID_SHARDLIGHT='ags:shardlight'
+APP_MAIN_SCUMMID_UNAVOWED='ags:unavowed'
+APP_MAIN_ICON='../support/icon.png'
+APP_MAIN_ICON_SHIVAH_0='Shivah.exe'
+APP_MAIN_ICON_GEMINIRUE_1='Gemini Rue.exe'
+APP_MAIN_ICON_GEMINIRUE_0='Gemini Rue.exe'
+APP_MAIN_ICON_RESONANCE_0='Resonance.exe'
+APP_MAIN_ICON_TECHNOBABYLON_1='Technobabylon.exe'
+APP_MAIN_ICON_TECHNOBABYLON_0='Technobabylon.exe'
+APP_MAIN_ICON_SHARDLIGHT_1='Shardlight.exe'
+APP_MAIN_ICON_SHARDLIGHT_0='Shardlight.exe'
+APP_MAIN_ICON_UNAVOWED_3='Unavowed.exe'
+APP_MAIN_ICON_UNAVOWED_2='Unavowed.exe'
+APP_MAIN_ICON_UNAVOWED_1='Unavowed.exe'
+APP_MAIN_ICON_UNAVOWED_0='Unavowed.exe'
 
 # Load common functions
 
@@ -217,131 +313,18 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Check for the presence of optional extra archives
-
-case "$(current_archive)" in
-	('ARCHIVE_BASE_SHIVAH_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='the-shivah_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='76cb6554e1c09596842391a71e696ded'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/the-shivah/'
-	;;
-	('ARCHIVE_BASE_GEMINIRUE_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='gemini-rue_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='329019f63b1acdfe7c4d5219a562efab'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/gemini-rue/'
-	;;
-	('ARCHIVE_BASE_RESONANCE_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='resonance_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='0a24712adffd9f5f2998bf355fc161b7'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/resonance/'
-	;;
-	('ARCHIVE_BASE_TECHNOBABYLON_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='technobabylon_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='84a7104801c25d5e931fbdd4cc3d1916'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/technobabylon/'
-	;;
-	('ARCHIVE_BASE_SHARDLIGHT_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='shardlight_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='59bce49abce9678d963cecd72be8b512'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/shardlight/'
-	;;
-	('ARCHIVE_BASE_UNAVOWED_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='unavowed_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='359eae49cc167a34a1cc5525cf6ab340'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/unavowed/'
-	;;
-esac
-archive_initialize_optional \
-	'ARCHIVE_ICONS' \
-	'ARCHIVE_OPTIONAL_ICONS'
-
 # Extract game data
 
 archive_extraction_default
-if archive_is_available 'ARCHIVE_ICONS'; then
-	archive_extraction 'ARCHIVE_ICONS'
-fi
 
 # Include game data
 
-if archive_is_available 'ARCHIVE_ICONS'; then
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_SHIVAH_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			24x24
-			32x32
-			48x48
-			256x256'
-		;;
-		('ARCHIVE_BASE_GEMINIRUE_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			256x256'
-		;;
-		('ARCHIVE_BASE_RESONANCE_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			24x24
-			32x32
-			48x48
-			256x256'
-		;;
-		('ARCHIVE_BASE_TECHNOBABYLON_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			64x64'
-		;;
-		('ARCHIVE_BASE_SHARDLIGHT_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			32x32'
-		;;
-		('ARCHIVE_BASE_UNAVOWED_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			24x24
-			32x32
-			48x48
-			256x256'
-		;;
-	esac
-	content_inclusion 'ICONS_DATA' 'PKG_MAIN' "$(path_icons)"
-else
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_SHIVAH_0')
-			APP_MAIN_ICON='Shivah.exe'
-		;;
-		('ARCHIVE_BASE_GEMINIRUE_0'|'ARCHIVE_BASE_GEMINIRUE_1')
-			APP_MAIN_ICON='Gemini Rue.exe'
-		;;
-		('ARCHIVE_BASE_RESONANCE_0')
-			APP_MAIN_ICON='Resonance.exe'
-		;;
-		('ARCHIVE_BASE_TECHNOBABYLON_0'|'ARCHIVE_BASE_TECHNOBABYLON_1')
-			APP_MAIN_ICON='Technobabylon.exe'
-		;;
-		('ARCHIVE_BASE_SHARDLIGHT_0'|'ARCHIVE_BASE_SHARDLIGHT_1')
-			APP_MAIN_ICON='Shardlight.exe'
-		;;
-		('ARCHIVE_BASE_UNAVOWED_0'|'ARCHIVE_BASE_UNAVOWED_1'|'ARCHIVE_BASE_UNAVOWED_2'|'ARCHIVE_BASE_UNAVOWED_3')
-			APP_MAIN_ICON='Unavowed.exe'
-		;;
-		(*)
-			APP_MAIN_ICON='../support/icon.png'
-		;;
-	esac
-	icons_inclusion
-fi
+content_inclusion_icons
 content_inclusion_default
 
 # Write launchers
 
-launchers_write
+launchers_generation
 
 # Build packages
 
