@@ -15,9 +15,9 @@ set -o errexit
 # - The Under Games
 ###
 
-script_version=20240524.1
+script_version=20240721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='war-for-the-overworld'
 GAME_NAME='War for the Overworld'
@@ -237,7 +237,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
 goggame-*.info'
 
-PKG_MAIN_DEPS="$GAME_ID"
+PKG_PARENT_ID="$GAME_ID"
+
+PKG_MAIN_DEPENDENCIES_SIBLINGS='
+PKG_PARENT'
 
 # Load common functions
 
