@@ -7,9 +7,9 @@ set -o errexit
 # Warcraft 1
 ###
 
-script_version=20240416.1
+script_version=20240719.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='warcraft-1'
 GAME_NAME='Warcraft: Orcs & Humans'
@@ -17,18 +17,18 @@ GAME_NAME='Warcraft: Orcs & Humans'
 ARCHIVE_BASE_0_NAME='setup_warcraft_orcs__humans_1.2_(28330).exe'
 ARCHIVE_BASE_0_MD5='79d30dbb24395d32f77156a2e2b4639c'
 ARCHIVE_BASE_0_TYPE='innosetup'
-ARCHIVE_BASE_0_SIZE='650000'
+ARCHIVE_BASE_0_SIZE='642266'
 ARCHIVE_BASE_0_VERSION='1.2-gog28330'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/warcraft_orcs_and_humans'
 
 CONTENT_PATH_DEFAULT='.'
 CONTENT_GAME_MAIN_FILES='
+data
+drivers
 *.bin
 *.cue
 *.exe
-*.war
-data
-drivers'
+*.war'
 CONTENT_DOC_MAIN_PATH='
 *.txt'
 
