@@ -7,9 +7,9 @@ set -o errexit
 # Warhammer 40k: Rogue Trader
 ###
 
-script_version=20240504.4
+script_version=20240720.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='warhammer-40k-rogue-trader'
 GAME_NAME='Warhammer 40,000: Rogue Trader'
@@ -87,12 +87,21 @@ PKG_DATA_BUNDLES_UNIT
 PKG_DATA_BUNDLES
 PKG_DATA'
 
+PKG_BIN_ARCH='64'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
+PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_BUNDLES'
 
 PKG_DATA_BUNDLES_ID="${PKG_DATA_ID}-bundles"
 PKG_DATA_BUNDLES_DESCRIPTION="$PKG_DATA_DESCRIPTION - bundles"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_BUNDLES_ID"
+PKG_DATA_BUNDLES_DEPENDENCIES_SIBLINGS='
+PKG_DATA_BUNDLES_SCENES_1
+PKG_DATA_BUNDLES_SCENES_2
+PKG_DATA_BUNDLES_UNIT'
 
 PKG_DATA_BUNDLES_SCENES_ID="${PKG_DATA_BUNDLES_ID}-scenes"
 PKG_DATA_BUNDLES_SCENES_1_ID="${PKG_DATA_BUNDLES_SCENES_ID}-1"
@@ -100,14 +109,9 @@ PKG_DATA_BUNDLES_SCENES_2_ID="${PKG_DATA_BUNDLES_SCENES_ID}-2"
 PKG_DATA_BUNDLES_SCENES_DESCRIPTION="$PKG_DATA_BUNDLES_DESCRIPTION - scenes"
 PKG_DATA_BUNDLES_SCENES_1_DESCRIPTION="$PKG_DATA_BUNDLES_SCENES_DESCRIPTION - 1"
 PKG_DATA_BUNDLES_SCENES_2_DESCRIPTION="$PKG_DATA_BUNDLES_SCENES_DESCRIPTION - 2"
-PKG_DATA_BUNDLES_DEPS="${PKG_DATA_BUNDLES_DEPS:-} $PKG_DATA_BUNDLES_SCENES_1_ID $PKG_DATA_BUNDLES_SCENES_2_ID"
 
 PKG_DATA_BUNDLES_UNIT_ID="${PKG_DATA_BUNDLES_ID}-unit"
 PKG_DATA_BUNDLES_UNIT_DESCRIPTION="$PKG_DATA_BUNDLES_DESCRIPTION - unit"
-PKG_DATA_BUNDLES_DEPS="${PKG_DATA_BUNDLES_DEPS:-} $PKG_DATA_BUNDLES_UNIT_ID"
-
-PKG_BIN_ARCH='64'
-PKG_BIN_DEPS="$PKG_DATA_ID"
 
 # Load common functions
 
