@@ -9,9 +9,9 @@ set -o errexit
 # World of Goo
 ###
 
-script_version=20240416.1
+script_version=20240719.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='world-of-goo'
 GAME_NAME='World of Goo'
@@ -21,7 +21,7 @@ GAME_NAME='World of Goo'
 ## Sold from gog.com
 ARCHIVE_BASE_GOG_0_NAME='world_of_goo_1_51_29337.sh'
 ARCHIVE_BASE_GOG_0_MD5='f3566d859e824862b4dc14f94b15cafa'
-ARCHIVE_BASE_GOG_0_SIZE='200000'
+ARCHIVE_BASE_GOG_0_SIZE='186520'
 ARCHIVE_BASE_GOG_0_VERSION='1.51-gog29337'
 ARCHIVE_BASE_GOG_0_URL='https://www.gog.com/game/world_of_goo'
 
@@ -63,14 +63,12 @@ PKG_BIN64
 PKG_BIN32
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
-
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-PKG_BIN64_DEPS="$PKG_BIN_DEPS"
-PKG_BIN32_DEPS="$PKG_BIN_DEPS"
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
+PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
@@ -81,6 +79,9 @@ libstdc++.so.6'
 PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
