@@ -7,9 +7,9 @@ set -o errexit
 # Worms 1
 ###
 
-script_version=20240416.1
+script_version=20240720.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='worms-1'
 GAME_NAME='Worms United'
@@ -17,7 +17,7 @@ GAME_NAME='Worms United'
 ARCHIVE_BASE_1_NAME='setup_worms_united_1.0_(28045).exe'
 ARCHIVE_BASE_1_MD5='fd76a7ea0a94f0e3e9cdd2b3b3f9fdd4'
 ARCHIVE_BASE_1_TYPE='innosetup'
-ARCHIVE_BASE_1_SIZE='210000'
+ARCHIVE_BASE_1_SIZE='206589'
 ARCHIVE_BASE_1_VERSION='1.0-gog28045'
 ARCHIVE_BASE_1_URL='https://www.gog.com/game/worms_united'
 
@@ -34,11 +34,11 @@ bin
 batch
 data
 extras
-worms*.ogg
+dos4gw.exe
 worms.cfg
 worms.dat
 worms.gog
-*.exe'
+worms*.ogg'
 CONTENT_DOC_MAIN_FILES='
 docs
 manual.pdf'
