@@ -10,9 +10,9 @@ set -o errexit
 # Worms: Armageddon
 ###
 
-script_version=20240416.1
+script_version=20240720.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.28'
+PLAYIT_COMPATIBILITY_LEVEL='2.30'
 
 GAME_ID='worms-armageddon'
 GAME_NAME='Worms: Armageddon'
@@ -20,7 +20,7 @@ GAME_NAME='Worms: Armageddon'
 ARCHIVE_BASE_3_NAME='setup_worms_armageddon_gog-3.8.1_(43454).exe'
 ARCHIVE_BASE_3_MD5='f84e60ba11363219c582a4ff65301692'
 ARCHIVE_BASE_3_TYPE='innosetup'
-ARCHIVE_BASE_3_SIZE='650000'
+ARCHIVE_BASE_3_SIZE='648070'
 ARCHIVE_BASE_3_VERSION='3.8.1-gog43454'
 ARCHIVE_BASE_3_URL='https://www.gog.com/game/worms_armageddon'
 
@@ -45,21 +45,30 @@ ARCHIVE_BASE_0_VERSION='3.7.2.1-gog2.0.0.2'
 CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_0='app'
 CONTENT_GAME_BIN_FILES='
-*.dll
-*.exe'
+lfcmp10n.dll
+ltfil10n.dll
+lfbmp10n.dll
+ltkrn10n.dll
+lflmb10n.dll
+lftga10n.dll
+wa.exe
+user/bankeditor.exe'
+## TODO: Check if the Steam library is required.
+CONTENT_GAME0_BIN_FILES='
+steam_api.dll'
 CONTENT_GAME_DATA_FILES='
 data
 fesfx
 graphics
 tweaks
 user'
-CONTENT_DOC_DATA_FILES='
-wa_manual.pdf
-worms armageddon update documentation.rtf'
 CONTENT_GAME0_DATA_PATH='__support'
 CONTENT_GAME0_DATA_PATH_0='app/__support'
 CONTENT_GAME0_DATA_FILES='
 save'
+CONTENT_DOC_DATA_FILES='
+wa_manual.pdf
+worms armageddon update documentation.rtf'
 
 USER_PERSISTENT_DIRECTORIES='
 save
@@ -69,7 +78,8 @@ graphics/font.bmp'
 
 APP_MAIN_EXE='wa.exe'
 ## Create a required empty file prior to game run.
-APP_MAIN_PRERUN='# Create required empty file prior to game run
+APP_MAIN_PRERUN='
+# Create a required empty file prior to game run
 touch steam.dat
 '
 
@@ -77,12 +87,13 @@ PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
 
+PKG_BIN_ARCH='32'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_DATA'
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_ARCH='32'
-PKG_BIN_DEPS="$PKG_DATA_ID"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -111,15 +122,6 @@ fi
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-	
-	# Drop unwanted files
-	rm --force --recursive \
-		'__redist' \
-		'commonappdata' \
-		'tmp'
-)
 
 # Include game data
 
