@@ -9,9 +9,9 @@ set -o errexit
 # - Strangeland
 ###
 
-script_version=20240127.1
+script_version=20240528.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID_PRIMORDIA='primordia'
 GAME_NAME_PRIMORDIA='Primordia'
@@ -23,11 +23,16 @@ GAME_NAME_STRANGELAND='Strangeland'
 
 ## Primordia
 
+ARCHIVE_BASE_PRIMORDIA_7_NAME='primordia_3_7_73438.sh'
+ARCHIVE_BASE_PRIMORDIA_7_MD5='8bae6792e72a9ac69263b6eb4f0e03e6'
+ARCHIVE_BASE_PRIMORDIA_7_SIZE='1426929'
+ARCHIVE_BASE_PRIMORDIA_7_VERSION='3.7-gog73438'
+ARCHIVE_BASE_PRIMORDIA_7_URL='https://www.gog.com/game/primordia'
+
 ARCHIVE_BASE_PRIMORDIA_6_NAME='primordia_3_6_70667.sh'
 ARCHIVE_BASE_PRIMORDIA_6_MD5='dc254ed674114e4776a91454e35d3741'
 ARCHIVE_BASE_PRIMORDIA_6_SIZE='1426928'
 ARCHIVE_BASE_PRIMORDIA_6_VERSION='3.6-gog70667'
-ARCHIVE_BASE_PRIMORDIA_6_URL='https://www.gog.com/game/primordia'
 
 ARCHIVE_BASE_PRIMORDIA_5_NAME='primordia_3_6_70159.sh'
 ARCHIVE_BASE_PRIMORDIA_5_MD5='d1f9eeec2084933463d1b43b5466f5f1'
@@ -59,6 +64,19 @@ ARCHIVE_BASE_PRIMORDIA_0_MD5='812917de017fde37b1c448f156e4ae7d'
 ARCHIVE_BASE_PRIMORDIA_0_SIZE='1500000'
 ARCHIVE_BASE_PRIMORDIA_0_VERSION='2.6-gog53699'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_PRIMORDIA='primordia_icons.tar.xz'
+ARCHIVE_OPTIONAL_ICONS_MD5_PRIMORDIA='66c1d186075708574ee870a9015b4ff6'
+ARCHIVE_OPTIONAL_ICONS_URL_PRIMORDIA='https://downloads.dotslashplay.it/games/primordia/'
+CONTENT_ICONS_PATH_PRIMORDIA='.'
+CONTENT_ICONS_FILES_PRIMORDIA='
+16x16
+24x24
+32x32
+48x48
+256x256'
+
 ## Strangeland
 
 ARCHIVE_BASE_STRANGELAND_3_NAME='strangeland_3_57270.sh'
@@ -98,7 +116,14 @@ Sounds
 CONTENT_DOC_MAIN_FILES='
 licenses'
 
-APP_MAIN_SCUMMID='ags'
+APP_MAIN_SCUMMID_PRIMORDIA='ags:primordia'
+APP_MAIN_SCUMMID_STRANGELAND='ags:strangeland'
+APP_MAIN_ICON='../support/icon.png'
+APP_MAIN_ICON_PRIMORDIA_2='Primordia.exe'
+APP_MAIN_ICON_PRIMORDIA_1='Primordia.exe'
+APP_MAIN_ICON_PRIMORDIA_0='Primordia.exe'
+## Strangeland.exe is too big, wrestool crashes when trying to handle it.
+APP_MAIN_ICON_STRANGELAND='winsetup.exe'
 
 # Load common functions
 
@@ -125,61 +150,18 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Check for the presence of optional extra archives
-
-case "$(current_archive)" in
-	('ARCHIVE_BASE_PRIMORDIA_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='primordia_icons.tar.xz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='66c1d186075708574ee870a9015b4ff6'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/primordia/'
-	;;
-esac
-archive_initialize_optional \
-	'ARCHIVE_ICONS' \
-	'ARCHIVE_OPTIONAL_ICONS'
-
 # Extract game data
 
 archive_extraction_default
-if archive_is_available 'ARCHIVE_ICONS'; then
-	archive_extraction 'ARCHIVE_ICONS'
-fi
 
 # Include game data
 
-if archive_is_available 'ARCHIVE_ICONS'; then
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_PRIMORDIA_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			24x24
-			32x32
-			48x48
-			256x256'
-		;;
-	esac
-	content_inclusion 'ICONS_DATA' 'PKG_MAIN' "$(path_icons)"
-else
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_PRIMORDIA_0'|'ARCHIVE_BASE_PRIMORDIA_1'|'ARCHIVE_BASE_PRIMORDIA_2')
-			APP_MAIN_ICON='Primordia.exe'
-		;;
-		('ARCHIVE_BASE_STRANGELAND_'*)
-			## Strangeland.exe is too big, wrestool crashes when trying to handle it.
-			APP_MAIN_ICON='winsetup.exe'
-		;;
-		(*)
-			APP_MAIN_ICON='../support/icon.png'
-		;;
-	esac
-	icons_inclusion
-fi
+content_inclusion_icons
 content_inclusion_default
 
 # Write launchers
 
-launchers_write
+launchers_generation
 
 # Build packages
 
